(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    534570,      12030]
NotebookOptionsPosition[    524980,      11868]
NotebookOutlinePosition[    525414,      11885]
CellTagsIndexPosition[    525371,      11882]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Initialisation", "Title",
 CellChangeTimes->{{3.802661949535056*^9, 
  3.802661955246132*^9}},ExpressionUUID->"ada8eced-57b5-4e95-9679-\
10c23e57e050"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["Y", "\[ScriptL]_"], "[", "\[Theta]_", "]"}], "=", 
   RowBox[{"SphericalHarmonicY", "[", 
    RowBox[{"\[ScriptL]", ",", "0", ",", "\[Theta]", ",", "\[Phi]"}], "]"}]}],
   ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7479296617902107`*^9, 3.747929685395328*^9}, {
  3.747929715401596*^9, 3.74792971615026*^9}, {3.747934844195202*^9, 
  3.747934858367525*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"cddd0ec0-6b45-4f98-97fa-10a30d36a12a"],

Cell[BoxData[{
 RowBox[{"Needs", "[", "\"\<MaTeX`\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"MaTeX", ",", 
    RowBox[{"\"\<Preamble\>\"", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "\"\<\\\\usepackage{amssymb,amsmath,latexsym,amsfonts,amsthm,mathpazo,\
xcolor,bm,mhchem}\>\"", ",", 
       "\"\<\\\\definecolor{darkgreen}{RGB}{0, 180, 0}\>\""}], "}"}]}]}], 
   "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.7288240181604652`*^9, 3.728824027007351*^9}, {
  3.733131339213026*^9, 3.733131352923026*^9}, {3.748749840810712*^9, 
  3.7487498700068483`*^9}, {3.7487499293939*^9, 3.748749970151113*^9}, {
  3.748750013043272*^9, 3.748750051449955*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"999c762a-7c58-4666-bb60-666ecc942fc6"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Spherium: RHF, UHF and symmetry breaking", "Title",
 CellChangeTimes->{{3.802661961504737*^9, 
  3.802661987945573*^9}},ExpressionUUID->"4fc18051-e9c0-4c5b-a384-\
aca352fcc60f"],

Cell["The general function for the Hartree-Fock energy is:", "Text",
 CellChangeTimes->{{3.802662078894106*^9, 
  3.802662099004736*^9}},ExpressionUUID->"0fbf1705-90d8-4972-a010-\
12f7a06f12e2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"EHF", "[", 
    RowBox[{"R_", ",", "\[Lambda]_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"L", "=", "0"}], "1"], 
      RowBox[{
       SubsuperscriptBox["a", "L", "2"], 
       FractionBox[
        RowBox[{"L", 
         RowBox[{"(", 
          RowBox[{"L", "+", "1"}], ")"}]}], 
        RowBox[{"2", 
         SuperscriptBox["R", "2"]}]]}]}], "+", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"L", "=", "0"}], "1"], 
      RowBox[{
       SubsuperscriptBox["b", "L", "2"], 
       FractionBox[
        RowBox[{"L", 
         RowBox[{"(", 
          RowBox[{"L", "+", "1"}], ")"}]}], 
        RowBox[{"2", 
         SuperscriptBox["R", "2"]}]]}]}], "+", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"i", "=", "0"}], "1"], 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"j", "=", "0"}], "1"], 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "1"], 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"l", "=", "0"}], "1"], 
         RowBox[{
          SubscriptBox["a", "i"], 
          SubscriptBox["a", "j"], 
          SubscriptBox["b", "k"], 
          SubscriptBox["b", "l"], 
          FractionBox["\[Lambda]", "R"], 
          SqrtBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "i"}], "+", "1"}], ")"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "j"}], "+", "1"}], ")"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "k"}], "+", "1"}], ")"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", "l"}], "+", "1"}], ")"}]}]], 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"L", "=", "0"}], "2"], 
           RowBox[{
            SuperscriptBox[
             RowBox[{"ThreeJSymbol", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"i", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"L", ",", "0"}], "}"}]}], "]"}], "2"], 
            SuperscriptBox[
             RowBox[{"ThreeJSymbol", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"k", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"l", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"L", ",", "0"}], "}"}]}], "]"}], "2"]}]}]}]}]}]}]}]}],
     "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "0"], "\[Rule]", 
       RowBox[{"Cos", "[", "x", "]"}]}], ",", 
      RowBox[{
       SubscriptBox["a", "1"], "\[Rule]", 
       RowBox[{"Sin", "[", "x", "]"}]}], ",", 
      RowBox[{
       SubscriptBox["b", "0"], "\[Rule]", 
       RowBox[{"Cos", "[", "y", "]"}]}], ",", 
      RowBox[{
       SubscriptBox["b", "1"], "\[Rule]", 
       RowBox[{"Sin", "[", "y", "]"}]}]}], "}"}]}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.747932533076035*^9, 3.747932594288992*^9}, {
   3.74793265743637*^9, 3.747932704311902*^9}, {3.747932747551168*^9, 
   3.747932752688005*^9}, {3.748106825492906*^9, 3.74810683088853*^9}, {
   3.7485394171937532`*^9, 3.748539430968988*^9}, {3.756878491371388*^9, 
   3.756878495249749*^9}, {3.756878659854623*^9, 3.756878698735498*^9}, {
   3.7568787384374228`*^9, 3.756878763102129*^9}, {3.758450637767758*^9, 
   3.758450693986443*^9}, {3.758450992161113*^9, 3.758451010282164*^9}, {
   3.75845322364914*^9, 3.7584532272944727`*^9}, {3.7584532867850018`*^9, 
   3.7584533019512243`*^9}, {3.758453913178156*^9, 3.7584539568489017`*^9}, 
   3.758454024097807*^9, {3.7584571709455137`*^9, 3.758457214991362*^9}, {
   3.758518339463217*^9, 3.758518385388159*^9}, {3.7585184447026052`*^9, 
   3.7585184473833857`*^9}, {3.7585185297567177`*^9, 3.758518608900483*^9}, {
   3.7585189644841957`*^9, 3.758519014634166*^9}, 3.758519045474049*^9, 
   3.758556116462696*^9, 3.758561058841317*^9, {3.759767814564877*^9, 
   3.759767896427142*^9}, {3.759767999319418*^9, 3.7597680202097797`*^9}, {
   3.759768120687716*^9, 3.759768147003292*^9}, {3.759768180425478*^9, 
   3.759768210125568*^9}, {3.7597682599610777`*^9, 3.759768265231473*^9}, 
   3.759768298989128*^9, {3.7597683711782427`*^9, 3.759768596445649*^9}, {
   3.759768654886559*^9, 3.759768683624309*^9}, {3.759769465854788*^9, 
   3.759769466333378*^9}, {3.76138775808783*^9, 3.761387773945417*^9}, {
   3.761387820479332*^9, 3.761387846655658*^9}, {3.761387881207934*^9, 
   3.761387993804481*^9}, {3.761388075525421*^9, 3.7613881363075457`*^9}, {
   3.76138818801961*^9, 3.761388205642667*^9}, {3.761388237701242*^9, 
   3.761388241994245*^9}, {3.761388422633017*^9, 3.761388457296768*^9}, 
   3.761388500834354*^9, {3.761388614471837*^9, 3.76138861727827*^9}, {
   3.7613887936463423`*^9, 3.76138880490932*^9}, 3.76138883551187*^9, 
   3.761388888118733*^9, 3.761389694848022*^9, 3.761389725480567*^9, {
   3.76139003654671*^9, 3.761390069585845*^9}, {3.761391624260129*^9, 
   3.76139172320362*^9}, {3.761391781274022*^9, 3.76139180641101*^9}, {
   3.76139192764214*^9, 3.761391955968897*^9}, {3.761392032275921*^9, 
   3.761392061135333*^9}, {3.7613921016004333`*^9, 3.761392104576024*^9}, {
   3.7613921404004507`*^9, 3.7613921548703413`*^9}, 3.761392214320422*^9, {
   3.761392255134748*^9, 3.76139228728538*^9}, {3.768662774164274*^9, 
   3.768662782501505*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"f6e7f160-010f-4779-b1d8-ea0c5ba6e8be"],

Cell[BoxData[
 TemplateBox[{
  "ClebschGordan", "tri", 
   "\"\\!\\(\\*RowBox[{\\\"ThreeJSymbol\\\", \\\"[\\\", RowBox[{RowBox[{\\\"{\
\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\
\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"0\\\"}], \
\\\"}\\\"}]}], \\\"]\\\"}]\\) is not triangular.\"", 2, 4, 1, 
   22573338086155504028, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8026621409422417`*^9, 3.802664021746966*^9},
 CellLabel->
  "During evaluation of \
In[4]:=",ExpressionUUID->"f43690ac-2534-4e52-bdc4-1b11abdb3894"],

Cell[BoxData[
 TemplateBox[{
  "ClebschGordan", "tri", 
   "\"\\!\\(\\*RowBox[{\\\"ThreeJSymbol\\\", \\\"[\\\", RowBox[{RowBox[{\\\"{\
\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\
\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"0\\\"}], \
\\\"}\\\"}]}], \\\"]\\\"}]\\) is not triangular.\"", 2, 4, 2, 
   22573338086155504028, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8026621409422417`*^9, 3.802664021773921*^9},
 CellLabel->
  "During evaluation of \
In[4]:=",ExpressionUUID->"6e1120df-ba71-4a86-a8bb-49a8e2ae428c"],

Cell[BoxData[
 TemplateBox[{
  "ClebschGordan", "tri", 
   "\"\\!\\(\\*RowBox[{\\\"ThreeJSymbol\\\", \\\"[\\\", RowBox[{RowBox[{\\\"{\
\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\
\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \\\"0\\\"}], \
\\\"}\\\"}]}], \\\"]\\\"}]\\) is not triangular.\"", 2, 4, 3, 
   22573338086155504028, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8026621409422417`*^9, 3.802664021780335*^9},
 CellLabel->
  "During evaluation of \
In[4]:=",ExpressionUUID->"ab2d3936-24d8-4f9d-8ec1-a120d0475c73"],

Cell[BoxData[
 TemplateBox[{
  "General", "stop", 
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"ClebschGordan\\\", \
\\\"::\\\", \\\"tri\\\"}], \\\"MessageName\\\"]\\) will be suppressed during \
this calculation.\"", 2, 4, 4, 22573338086155504028, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8026621409422417`*^9, 3.802664021786839*^9},
 CellLabel->
  "During evaluation of \
In[4]:=",ExpressionUUID->"101a719a-022c-4807-b0cb-e7e72c39686f"]
}, Open  ]],

Cell["We search stationnary solution", "Text",
 CellChangeTimes->{{3.8026621457056427`*^9, 
  3.802662152137005*^9}},ExpressionUUID->"231d3157-529b-4bc7-a840-\
df39d8f184e9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          SubscriptBox["\[PartialD]", "x"], 
          RowBox[{"EHF", "[", 
           RowBox[{"R", ",", "1"}], "]"}]}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[PartialD]", "y"], 
          RowBox[{"EHF", "[", 
           RowBox[{"R", ",", "1"}], "]"}]}], "\[Equal]", "0"}]}], "}"}], ",", 
      
      RowBox[{"{", 
       RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"C", "[", "1", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"C", "[", "2", "]"}], "\[Rule]", "0"}]}], "}"}]}], "//", 
   "FullSimplify"}]}]], "Input",
 CellLabel->"In[62]:=",ExpressionUUID->"6602dda8-5b82-4835-a2a6-e1e0a1c0e32e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "0"}], ",", 
     RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "0"}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "0"}], ",", 
     RowBox[{"y", "\[Rule]", 
      FractionBox["\[Pi]", "2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "0"}], ",", 
     RowBox[{"y", "\[Rule]", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}]}], ",", 
     RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      FractionBox["\[Pi]", "2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}]}], ",", 
     RowBox[{"y", "\[Rule]", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      FractionBox["\[Pi]", "2"]}], ",", 
     RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      FractionBox["\[Pi]", "2"]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      FractionBox["\[Pi]", "2"]}], ",", 
     RowBox[{"y", "\[Rule]", 
      FractionBox["\[Pi]", "2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      FractionBox["\[Pi]", "2"]}], ",", 
     RowBox[{"y", "\[Rule]", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "\[Pi]"}], ",", 
     RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "\[Pi]"}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "\[Pi]"}], ",", 
     RowBox[{"y", "\[Rule]", 
      FractionBox["\[Pi]", "2"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "\[Pi]"}], ",", 
     RowBox[{"y", "\[Rule]", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SqrtBox[
           RowBox[{
            RowBox[{"-", "75"}], "+", 
            RowBox[{"38", " ", "R"}]}]], 
          SqrtBox["R"]]}], ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", " ", 
           SqrtBox[
            RowBox[{"3", "+", 
             RowBox[{"2", " ", "R"}]}]]}], 
          SqrtBox["R"]]}]}], "]"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SqrtBox[
           RowBox[{
            RowBox[{"-", "75"}], "+", 
            RowBox[{"38", " ", "R"}]}]], 
          SqrtBox["R"]]}], ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", " ", 
           SqrtBox[
            RowBox[{"3", "+", 
             RowBox[{"2", " ", "R"}]}]]}], 
          SqrtBox["R"]]}]}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SqrtBox[
           RowBox[{
            RowBox[{"-", "75"}], "+", 
            RowBox[{"38", " ", "R"}]}]], 
          SqrtBox["R"]]}], ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", " ", 
           SqrtBox[
            RowBox[{"3", "+", 
             RowBox[{"2", " ", "R"}]}]]}], 
          SqrtBox["R"]]}]}], "]"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        FractionBox[
         SqrtBox[
          RowBox[{
           RowBox[{"-", "75"}], "+", 
           RowBox[{"38", " ", "R"}]}]], 
         SqrtBox["R"]], ",", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{"3", "+", 
            RowBox[{"2", " ", "R"}]}]]}], 
         SqrtBox["R"]]}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SqrtBox[
           RowBox[{
            RowBox[{"-", "75"}], "+", 
            RowBox[{"38", " ", "R"}]}]], 
          SqrtBox["R"]]}], ",", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{"3", "+", 
            RowBox[{"2", " ", "R"}]}]]}], 
         SqrtBox["R"]]}], "]"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SqrtBox[
           RowBox[{
            RowBox[{"-", "75"}], "+", 
            RowBox[{"38", " ", "R"}]}]], 
          SqrtBox["R"]]}], ",", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{"3", "+", 
            RowBox[{"2", " ", "R"}]}]]}], 
         SqrtBox["R"]]}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SqrtBox[
           RowBox[{
            RowBox[{"-", "75"}], "+", 
            RowBox[{"38", " ", "R"}]}]], 
          SqrtBox["R"]]}], ",", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{"3", "+", 
            RowBox[{"2", " ", "R"}]}]]}], 
         SqrtBox["R"]]}], "]"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        FractionBox[
         SqrtBox[
          RowBox[{
           RowBox[{"-", "75"}], "+", 
           RowBox[{"38", " ", "R"}]}]], 
         SqrtBox["R"]], ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", " ", 
           SqrtBox[
            RowBox[{"3", "+", 
             RowBox[{"2", " ", "R"}]}]]}], 
          SqrtBox["R"]]}]}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        FractionBox[
         SqrtBox[
          RowBox[{
           RowBox[{"-", "75"}], "+", 
           RowBox[{"38", " ", "R"}]}]], 
         SqrtBox["R"]], ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", " ", 
           SqrtBox[
            RowBox[{"3", "+", 
             RowBox[{"2", " ", "R"}]}]]}], 
          SqrtBox["R"]]}]}], "]"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SqrtBox[
           RowBox[{
            RowBox[{"-", "75"}], "+", 
            RowBox[{"38", " ", "R"}]}]], 
          SqrtBox["R"]]}], ",", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{"3", "+", 
            RowBox[{"2", " ", "R"}]}]]}], 
         SqrtBox["R"]]}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        FractionBox[
         SqrtBox[
          RowBox[{
           RowBox[{"-", "75"}], "+", 
           RowBox[{"38", " ", "R"}]}]], 
         SqrtBox["R"]], ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", " ", 
           SqrtBox[
            RowBox[{"3", "+", 
             RowBox[{"2", " ", "R"}]}]]}], 
          SqrtBox["R"]]}]}], "]"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        FractionBox[
         SqrtBox[
          RowBox[{
           RowBox[{"-", "75"}], "+", 
           RowBox[{"38", " ", "R"}]}]], 
         SqrtBox["R"]], ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", " ", 
           SqrtBox[
            RowBox[{"3", "+", 
             RowBox[{"2", " ", "R"}]}]]}], 
          SqrtBox["R"]]}]}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        FractionBox[
         SqrtBox[
          RowBox[{
           RowBox[{"-", "75"}], "+", 
           RowBox[{"38", " ", "R"}]}]], 
         SqrtBox["R"]], ",", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{"3", "+", 
            RowBox[{"2", " ", "R"}]}]]}], 
         SqrtBox["R"]]}], "]"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SqrtBox[
           RowBox[{
            RowBox[{"-", "75"}], "+", 
            RowBox[{"38", " ", "R"}]}]], 
          SqrtBox["R"]]}], ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", " ", 
           SqrtBox[
            RowBox[{"3", "+", 
             RowBox[{"2", " ", "R"}]}]]}], 
          SqrtBox["R"]]}]}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        FractionBox[
         SqrtBox[
          RowBox[{
           RowBox[{"-", "75"}], "+", 
           RowBox[{"38", " ", "R"}]}]], 
         SqrtBox["R"]], ",", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{"3", "+", 
            RowBox[{"2", " ", "R"}]}]]}], 
         SqrtBox["R"]]}], "]"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        FractionBox[
         SqrtBox[
          RowBox[{
           RowBox[{"-", "75"}], "+", 
           RowBox[{"38", " ", "R"}]}]], 
         SqrtBox["R"]], ",", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{"3", "+", 
            RowBox[{"2", " ", "R"}]}]]}], 
         SqrtBox["R"]]}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]], 
          SqrtBox["R"]]}], ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"2", " ", "R"}]}]]}], 
          SqrtBox["R"]]}]}], "]"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]], 
          SqrtBox["R"]]}], ",", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]]}], 
         SqrtBox["R"]]}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]], 
          SqrtBox["R"]]}], ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"2", " ", "R"}]}]]}], 
          SqrtBox["R"]]}]}], "]"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        FractionBox[
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]], 
         SqrtBox["R"]], ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"2", " ", "R"}]}]]}], 
          SqrtBox["R"]]}]}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]], 
          SqrtBox["R"]]}], ",", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]]}], 
         SqrtBox["R"]]}], "]"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]], 
          SqrtBox["R"]]}], ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"2", " ", "R"}]}]]}], 
          SqrtBox["R"]]}]}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]], 
          SqrtBox["R"]]}], ",", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]]}], 
         SqrtBox["R"]]}], "]"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        FractionBox[
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]], 
         SqrtBox["R"]], ",", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]]}], 
         SqrtBox["R"]]}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        FractionBox[
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]], 
         SqrtBox["R"]], ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"2", " ", "R"}]}]]}], 
          SqrtBox["R"]]}]}], "]"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]], 
          SqrtBox["R"]]}], ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"2", " ", "R"}]}]]}], 
          SqrtBox["R"]]}]}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        FractionBox[
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]], 
         SqrtBox["R"]], ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"2", " ", "R"}]}]]}], 
          SqrtBox["R"]]}]}], "]"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        FractionBox[
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]], 
         SqrtBox["R"]], ",", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]]}], 
         SqrtBox["R"]]}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        FractionBox[
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]], 
         SqrtBox["R"]], ",", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]]}], 
         SqrtBox["R"]]}], "]"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]], 
          SqrtBox["R"]]}], ",", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]]}], 
         SqrtBox["R"]]}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        FractionBox[
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]], 
         SqrtBox["R"]], ",", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]]}], 
         SqrtBox["R"]]}], "]"}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{"ArcTan", "[", 
       RowBox[{
        FractionBox[
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]], 
         SqrtBox["R"]], ",", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"5", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"2", " ", "R"}]}]]}], 
          SqrtBox["R"]]}]}], "]"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.802662142115428*^9, 3.802667884393529*^9},
 CellLabel->"Out[62]=",ExpressionUUID->"83464c67-066b-4f31-832c-f92b96a255d9"]
}, Open  ]],

Cell["\<\
Some solutions correspond to RHF solutions et some to UHF solutions.\
\>", "Text",
 CellChangeTimes->{{3.802662522192679*^9, 3.8026625271308413`*^9}, {
  3.802662593223194*^9, 
  3.802662618617*^9}},ExpressionUUID->"8ada797e-51a3-42f5-9b78-7dc023472d79"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solRHF", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        FractionBox["\[Pi]", "2"]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        FractionBox["\[Pi]", "2"]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        FractionBox["\[Pi]", "2"]}], ",", 
       RowBox[{"y", "\[Rule]", 
        FractionBox["\[Pi]", "2"]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "\[Pi]"}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "\[Pi]"}], ",", 
       RowBox[{"y", "\[Rule]", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SqrtBox[
             RowBox[{
              RowBox[{"-", "75"}], "+", 
              RowBox[{"38", " ", "R"}]}]], 
            SqrtBox["R"]]}], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{"3", "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SqrtBox[
             RowBox[{
              RowBox[{"-", "75"}], "+", 
              RowBox[{"38", " ", "R"}]}]], 
            SqrtBox["R"]]}], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{"3", "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SqrtBox[
             RowBox[{
              RowBox[{"-", "75"}], "+", 
              RowBox[{"38", " ", "R"}]}]], 
            SqrtBox["R"]]}], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{"3", "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{
             RowBox[{"-", "75"}], "+", 
             RowBox[{"38", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          FractionBox[
           RowBox[{"5", " ", 
            SqrtBox[
             RowBox[{"3", "+", 
              RowBox[{"2", " ", "R"}]}]]}], 
           SqrtBox["R"]]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SqrtBox[
             RowBox[{
              RowBox[{"-", "75"}], "+", 
              RowBox[{"38", " ", "R"}]}]], 
            SqrtBox["R"]]}], ",", 
          FractionBox[
           RowBox[{"5", " ", 
            SqrtBox[
             RowBox[{"3", "+", 
              RowBox[{"2", " ", "R"}]}]]}], 
           SqrtBox["R"]]}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SqrtBox[
             RowBox[{
              RowBox[{"-", "75"}], "+", 
              RowBox[{"38", " ", "R"}]}]], 
            SqrtBox["R"]]}], ",", 
          FractionBox[
           RowBox[{"5", " ", 
            SqrtBox[
             RowBox[{"3", "+", 
              RowBox[{"2", " ", "R"}]}]]}], 
           SqrtBox["R"]]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SqrtBox[
             RowBox[{
              RowBox[{"-", "75"}], "+", 
              RowBox[{"38", " ", "R"}]}]], 
            SqrtBox["R"]]}], ",", 
          FractionBox[
           RowBox[{"5", " ", 
            SqrtBox[
             RowBox[{"3", "+", 
              RowBox[{"2", " ", "R"}]}]]}], 
           SqrtBox["R"]]}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{
             RowBox[{"-", "75"}], "+", 
             RowBox[{"38", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{"3", "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{
             RowBox[{"-", "75"}], "+", 
             RowBox[{"38", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{"3", "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SqrtBox[
             RowBox[{
              RowBox[{"-", "75"}], "+", 
              RowBox[{"38", " ", "R"}]}]], 
            SqrtBox["R"]]}], ",", 
          FractionBox[
           RowBox[{"5", " ", 
            SqrtBox[
             RowBox[{"3", "+", 
              RowBox[{"2", " ", "R"}]}]]}], 
           SqrtBox["R"]]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{
             RowBox[{"-", "75"}], "+", 
             RowBox[{"38", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{"3", "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{
             RowBox[{"-", "75"}], "+", 
             RowBox[{"38", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{"3", "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{
             RowBox[{"-", "75"}], "+", 
             RowBox[{"38", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          FractionBox[
           RowBox[{"5", " ", 
            SqrtBox[
             RowBox[{"3", "+", 
              RowBox[{"2", " ", "R"}]}]]}], 
           SqrtBox["R"]]}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SqrtBox[
             RowBox[{
              RowBox[{"-", "75"}], "+", 
              RowBox[{"38", " ", "R"}]}]], 
            SqrtBox["R"]]}], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{"3", "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{
             RowBox[{"-", "75"}], "+", 
             RowBox[{"38", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          FractionBox[
           RowBox[{"5", " ", 
            SqrtBox[
             RowBox[{"3", "+", 
              RowBox[{"2", " ", "R"}]}]]}], 
           SqrtBox["R"]]}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{
             RowBox[{"-", "75"}], "+", 
             RowBox[{"38", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          FractionBox[
           RowBox[{"5", " ", 
            SqrtBox[
             RowBox[{"3", "+", 
              RowBox[{"2", " ", "R"}]}]]}], 
           SqrtBox["R"]]}], "]"}]}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.8026626442062902`*^9, 3.802662694832094*^9}, {
   3.802662889576977*^9, 3.8026629401653843`*^9}, 3.802663210947213*^9, {
   3.802664497947946*^9, 3.802664519827835*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"bc0a02bd-ce9f-4092-ba29-455868247a72"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solUHF", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        FractionBox["\[Pi]", "2"]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}]}], ",", 
       RowBox[{"y", "\[Rule]", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        FractionBox["\[Pi]", "2"]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        FractionBox["\[Pi]", "2"]}], ",", 
       RowBox[{"y", "\[Rule]", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "\[Pi]"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "\[Pi]"}], ",", 
       RowBox[{"y", "\[Rule]", 
        FractionBox["\[Pi]", "2"]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SqrtBox[
             RowBox[{"75", "+", 
              RowBox[{"62", " ", "R"}]}]], 
            SqrtBox["R"]]}], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SqrtBox[
             RowBox[{"75", "+", 
              RowBox[{"62", " ", "R"}]}]], 
            SqrtBox["R"]]}], ",", 
          FractionBox[
           RowBox[{"5", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "3"}], "+", 
              RowBox[{"2", " ", "R"}]}]]}], 
           SqrtBox["R"]]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SqrtBox[
             RowBox[{"75", "+", 
              RowBox[{"62", " ", "R"}]}]], 
            SqrtBox["R"]]}], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{"75", "+", 
             RowBox[{"62", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SqrtBox[
             RowBox[{"75", "+", 
              RowBox[{"62", " ", "R"}]}]], 
            SqrtBox["R"]]}], ",", 
          FractionBox[
           RowBox[{"5", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "3"}], "+", 
              RowBox[{"2", " ", "R"}]}]]}], 
           SqrtBox["R"]]}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SqrtBox[
             RowBox[{"75", "+", 
              RowBox[{"62", " ", "R"}]}]], 
            SqrtBox["R"]]}], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SqrtBox[
             RowBox[{"75", "+", 
              RowBox[{"62", " ", "R"}]}]], 
            SqrtBox["R"]]}], ",", 
          FractionBox[
           RowBox[{"5", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "3"}], "+", 
              RowBox[{"2", " ", "R"}]}]]}], 
           SqrtBox["R"]]}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{"75", "+", 
             RowBox[{"62", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          FractionBox[
           RowBox[{"5", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "3"}], "+", 
              RowBox[{"2", " ", "R"}]}]]}], 
           SqrtBox["R"]]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{"75", "+", 
             RowBox[{"62", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SqrtBox[
             RowBox[{"75", "+", 
              RowBox[{"62", " ", "R"}]}]], 
            SqrtBox["R"]]}], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{"75", "+", 
             RowBox[{"62", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{"75", "+", 
             RowBox[{"62", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          FractionBox[
           RowBox[{"5", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "3"}], "+", 
              RowBox[{"2", " ", "R"}]}]]}], 
           SqrtBox["R"]]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{"75", "+", 
             RowBox[{"62", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          FractionBox[
           RowBox[{"5", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "3"}], "+", 
              RowBox[{"2", " ", "R"}]}]]}], 
           SqrtBox["R"]]}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            SqrtBox[
             RowBox[{"75", "+", 
              RowBox[{"62", " ", "R"}]}]], 
            SqrtBox["R"]]}], ",", 
          FractionBox[
           RowBox[{"5", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "3"}], "+", 
              RowBox[{"2", " ", "R"}]}]]}], 
           SqrtBox["R"]]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{"75", "+", 
             RowBox[{"62", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          FractionBox[
           RowBox[{"5", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "3"}], "+", 
              RowBox[{"2", " ", "R"}]}]]}], 
           SqrtBox["R"]]}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{"75", "+", 
             RowBox[{"62", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.8026629431991034`*^9, 3.802662975615595*^9}, {
  3.802663168265376*^9, 3.802663225861127*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"a0467d14-fb57-4673-a6fc-eaba9b401d4f"],

Cell["The two electrons integrals are equal to", "Text",
 CellChangeTimes->{{3.802663258848398*^9, 
  3.8026632691674337`*^9}},ExpressionUUID->"5284d7aa-c7f1-4ca8-913e-\
1f30fc96cd74"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["U", 
    RowBox[{"i_", ",", "j_", ",", "k_", ",", "l_"}]], ":=", 
   RowBox[{
    SqrtBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "i"}], "+", "1"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "j"}], "+", "1"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "k"}], "+", "1"}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", "l"}], "+", "1"}], ")"}]}]], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"L", "=", "0"}], "2"], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"ThreeJSymbol", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"i", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"L", ",", "0"}], "}"}]}], "]"}], "2"], 
      SuperscriptBox[
       RowBox[{"ThreeJSymbol", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"k", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"l", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"L", ",", "0"}], "}"}]}], "]"}], "2"]}]}]}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellLabel->"In[6]:=",ExpressionUUID->"89897658-b4e4-4283-b38e-d848aa34e2ac"],

Cell["The Fock operator for the electron \[Alpha] is", "Text",
 CellChangeTimes->{{3.8026632969749527`*^9, 3.8026632973595877`*^9}, {
  3.802663524363038*^9, 3.802663542547873*^9}, {3.802663601069314*^9, 
  3.802663602598217*^9}},ExpressionUUID->"129c7a17-7cbb-4633-8227-\
b25198d13382"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F\[Alpha]", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"KroneckerDelta", "[", 
           RowBox[{"i", ",", "j"}], "]"}], 
          FractionBox[
           RowBox[{"i", 
            RowBox[{"(", 
             RowBox[{"i", "+", "1"}], ")"}]}], 
           RowBox[{"2", 
            SuperscriptBox["R", "2"]}]]}], "+", 
         RowBox[{
          FractionBox["\[Lambda]", "R"], 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "0"}], "1"], 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"l", "=", "0"}], "1"], 
            RowBox[{
             SubscriptBox["a", "k"], 
             SubscriptBox["a", "l"], 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["U", 
                RowBox[{"i", ",", "j", ",", "k", ",", "l"}]], "-", 
               SubscriptBox["U", 
                RowBox[{"i", ",", "l", ",", "k", ",", "j"}]]}], ")"}]}]}]}]}],
          "+", 
         RowBox[{
          FractionBox["\[Lambda]", "R"], 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "0"}], "1"], 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"l", "=", "0"}], "1"], 
            RowBox[{
             SubscriptBox["b", "k"], 
             SubscriptBox["b", "l"], 
             RowBox[{"(", 
              SubscriptBox["U", 
               RowBox[{"i", ",", "j", ",", "k", ",", "l"}]], ")"}]}]}]}]}]}], 
        "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubscriptBox["a", "0"], "\[Rule]", 
           RowBox[{"Cos", "[", "x", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["a", "1"], "\[Rule]", 
           RowBox[{"Sin", "[", "x", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["b", "0"], "\[Rule]", 
           RowBox[{"Cos", "[", "y", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["b", "1"], "\[Rule]", 
           RowBox[{"Sin", "[", "y", "]"}]}]}], "}"}]}], "/.", 
       RowBox[{"\[Lambda]", "\[Rule]", "1"}]}], "//", "FullSimplify"}], "//", 
     "Expand"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.802663565597023*^9, 3.802663581364587*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"24664069-d643-46e2-b730-262853885865"],

Cell[BoxData[
 TemplateBox[{
  "ClebschGordan", "tri", 
   "\"\\!\\(\\*RowBox[{\\\"ThreeJSymbol\\\", \\\"[\\\", RowBox[{RowBox[{\\\"{\
\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\
\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"0\\\"}], \
\\\"}\\\"}]}], \\\"]\\\"}]\\) is not triangular.\"", 2, 7, 5, 
   22573338086155504028, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.802664051564028*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"2a50fb86-b8d7-40ae-ab20-633f5f3b2658"],

Cell[BoxData[
 TemplateBox[{
  "ClebschGordan", "tri", 
   "\"\\!\\(\\*RowBox[{\\\"ThreeJSymbol\\\", \\\"[\\\", RowBox[{RowBox[{\\\"{\
\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\
\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"0\\\"}], \
\\\"}\\\"}]}], \\\"]\\\"}]\\) is not triangular.\"", 2, 7, 6, 
   22573338086155504028, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.802664051573551*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"8e5f854e-ea62-408b-b6d4-660ed995520d"],

Cell[BoxData[
 TemplateBox[{
  "ClebschGordan", "tri", 
   "\"\\!\\(\\*RowBox[{\\\"ThreeJSymbol\\\", \\\"[\\\", RowBox[{RowBox[{\\\"{\
\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\
\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \\\"0\\\"}], \
\\\"}\\\"}]}], \\\"]\\\"}]\\) is not triangular.\"", 2, 7, 7, 
   22573338086155504028, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.802664051580594*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"a97faec4-d943-42c9-8686-d309da1ca613"],

Cell[BoxData[
 TemplateBox[{
  "General", "stop", 
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"ClebschGordan\\\", \
\\\"::\\\", \\\"tri\\\"}], \\\"MessageName\\\"]\\) will be suppressed during \
this calculation.\"", 2, 7, 8, 22573338086155504028, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.8026640515892973`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"7780729a-83df-42f3-9fb1-5b27a8689551"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", 
       RowBox[{"3", " ", "R"}]], "-", 
      FractionBox[
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", "x"}], "]"}], 
       RowBox[{"3", " ", "R"}]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "x"}], "]"}], 
        RowBox[{"3", " ", "R"}]]}], "+", 
      FractionBox[
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", "y"}], "]"}], 
       RowBox[{"3", " ", "R"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "x"}], "]"}], 
        RowBox[{"3", " ", "R"}]]}], "+", 
      FractionBox[
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", "y"}], "]"}], 
       RowBox[{"3", " ", "R"}]]}], ",", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["R", "2"]], "+", 
      FractionBox["106", 
       RowBox[{"75", " ", "R"}]], "+", 
      FractionBox[
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", "x"}], "]"}], 
       RowBox[{"3", " ", "R"}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "y"}], "]"}]}], 
       RowBox[{"25", " ", "R"}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.802664051881092*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"846297c3-7ab4-4c69-aa0e-df2c493ae434"]
}, Open  ]],

Cell["And the Fock operator \[Beta]", "Text",
 CellChangeTimes->{{3.8026635891749487`*^9, 
  3.80266359899522*^9}},ExpressionUUID->"0f3e01cd-58e9-4bf5-b1bd-\
194abb9bf7b5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F\[Beta]", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"KroneckerDelta", "[", 
           RowBox[{"i", ",", "j"}], "]"}], 
          FractionBox[
           RowBox[{"i", 
            RowBox[{"(", 
             RowBox[{"i", "+", "1"}], ")"}]}], 
           RowBox[{"2", 
            SuperscriptBox["R", "2"]}]]}], "+", 
         RowBox[{
          FractionBox["\[Lambda]", "R"], 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "0"}], "1"], 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"l", "=", "0"}], "1"], 
            RowBox[{
             SubscriptBox["b", "k"], 
             SubscriptBox["b", "l"], 
             RowBox[{"(", 
              RowBox[{
               SubscriptBox["U", 
                RowBox[{"i", ",", "j", ",", "k", ",", "l"}]], "-", 
               SubscriptBox["U", 
                RowBox[{"i", ",", "l", ",", "k", ",", "j"}]]}], ")"}]}]}]}]}],
          "+", 
         RowBox[{
          FractionBox["\[Lambda]", "R"], 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"k", "=", "0"}], "1"], 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"l", "=", "0"}], "1"], 
            RowBox[{
             SubscriptBox["a", "k"], 
             SubscriptBox["a", "l"], 
             RowBox[{"(", 
              SubscriptBox["U", 
               RowBox[{"i", ",", "j", ",", "k", ",", "l"}]], ")"}]}]}]}]}]}], 
        "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SubscriptBox["a", "0"], "\[Rule]", 
           RowBox[{"Cos", "[", "x", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["a", "1"], "\[Rule]", 
           RowBox[{"Sin", "[", "x", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["b", "0"], "\[Rule]", 
           RowBox[{"Cos", "[", "y", "]"}]}], ",", 
          RowBox[{
           SubscriptBox["b", "1"], "\[Rule]", 
           RowBox[{"Sin", "[", "y", "]"}]}]}], "}"}]}], "/.", 
       RowBox[{"\[Lambda]", "\[Rule]", "1"}]}], "//", "FullSimplify"}], "//", 
     "Expand"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "0", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.802663616778529*^9, 3.8026636348017263`*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"858e2df5-f32c-46a7-986d-ee0dd3dd1489"],

Cell[BoxData[
 TemplateBox[{
  "ClebschGordan", "tri", 
   "\"\\!\\(\\*RowBox[{\\\"ThreeJSymbol\\\", \\\"[\\\", RowBox[{RowBox[{\\\"{\
\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\
\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"0\\\"}], \
\\\"}\\\"}]}], \\\"]\\\"}]\\) is not triangular.\"", 2, 8, 9, 
   22573338086155504028, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.802664056552679*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"133106f4-2a95-41aa-a9ca-28ca606939bd"],

Cell[BoxData[
 TemplateBox[{
  "ClebschGordan", "tri", 
   "\"\\!\\(\\*RowBox[{\\\"ThreeJSymbol\\\", \\\"[\\\", RowBox[{RowBox[{\\\"{\
\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\
\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"0\\\"}], \
\\\"}\\\"}]}], \\\"]\\\"}]\\) is not triangular.\"", 2, 8, 10, 
   22573338086155504028, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.802664056562199*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"fba4887c-6d05-49e9-886c-61e56f50e3a4"],

Cell[BoxData[
 TemplateBox[{
  "ClebschGordan", "tri", 
   "\"\\!\\(\\*RowBox[{\\\"ThreeJSymbol\\\", \\\"[\\\", RowBox[{RowBox[{\\\"{\
\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\",\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"0\\\"}], \\\"}\\\"}], \\\
\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \\\"0\\\"}], \
\\\"}\\\"}]}], \\\"]\\\"}]\\) is not triangular.\"", 2, 8, 11, 
   22573338086155504028, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.80266405656892*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"32108298-0b16-4037-ba7a-91581c79bf6f"],

Cell[BoxData[
 TemplateBox[{
  "General", "stop", 
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"ClebschGordan\\\", \
\\\"::\\\", \\\"tri\\\"}], \\\"MessageName\\\"]\\) will be suppressed during \
this calculation.\"", 2, 8, 12, 22573338086155504028, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.802664056579774*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"d195f59e-76b0-4895-92bd-104a79b47961"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", 
       RowBox[{"3", " ", "R"}]], "-", 
      FractionBox[
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", "y"}], "]"}], 
       RowBox[{"3", " ", "R"}]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", "x"}], "]"}], 
       RowBox[{"3", " ", "R"}]], "-", 
      FractionBox[
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", "y"}], "]"}], 
       RowBox[{"3", " ", "R"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", "x"}], "]"}], 
       RowBox[{"3", " ", "R"}]], "-", 
      FractionBox[
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", "y"}], "]"}], 
       RowBox[{"3", " ", "R"}]]}], ",", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["R", "2"]], "+", 
      FractionBox["106", 
       RowBox[{"75", " ", "R"}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "x"}], "]"}]}], 
       RowBox[{"25", " ", "R"}]], "+", 
      FractionBox[
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", "y"}], "]"}], 
       RowBox[{"3", " ", "R"}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.802664056777917*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"d3c978a7-f654-42e8-9d18-ac84427124ce"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RHF solutions", "Section",
 CellChangeTimes->{{3.8026637309017076`*^9, 
  3.802663739823473*^9}},ExpressionUUID->"8bc81dc5-3e8b-48e8-9f7a-\
d3219da34091"],

Cell["In the RHF case F\[Alpha] = F\[Beta]", "Text",
 CellChangeTimes->{{3.80266385074058*^9, 
  3.802663863596158*^9}},ExpressionUUID->"4592d0bc-14a6-441d-b2c8-\
840c4f56bace"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"F\[Alpha]", "/.", "solRHF"}], "//", "FullSimplify"}], "//", 
  "Expand"}]], "Input",
 CellChangeTimes->{{3.8026638781123657`*^9, 3.802663886744072*^9}, {
  3.802664071761154*^9, 3.80266408231196*^9}, {3.802664114117106*^9, 
  3.802664122098942*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"3abfa35e-224a-4093-b094-7ec8ae51fcc0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "R"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["5", 
         RowBox[{"3", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "R"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["5", 
         RowBox[{"3", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["5", 
        RowBox[{"3", " ", "R"}]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["29", 
         RowBox[{"25", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["5", 
        RowBox[{"3", " ", "R"}]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["29", 
         RowBox[{"25", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["5", 
        RowBox[{"3", " ", "R"}]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["29", 
         RowBox[{"25", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["5", 
        RowBox[{"3", " ", "R"}]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["29", 
         RowBox[{"25", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "R"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["5", 
         RowBox[{"3", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "R"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["5", 
         RowBox[{"3", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.80266454238374*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"1358b260-fa3c-43c8-8085-d0506d6c1731"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"F\[Beta]", "/.", "solRHF"}], "//", "FullSimplify"}], "//", 
  "Expand"}]], "Input",
 CellChangeTimes->{{3.802663935027121*^9, 3.8026639366247807`*^9}, {
  3.8026641361103973`*^9, 3.802664147259985*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"a0575948-9a8d-4e4e-95a4-9d9847c0e597"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "R"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["5", 
         RowBox[{"3", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "R"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["5", 
         RowBox[{"3", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["5", 
        RowBox[{"3", " ", "R"}]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["29", 
         RowBox[{"25", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["5", 
        RowBox[{"3", " ", "R"}]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["29", 
         RowBox[{"25", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["5", 
        RowBox[{"3", " ", "R"}]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["29", 
         RowBox[{"25", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["5", 
        RowBox[{"3", " ", "R"}]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["29", 
         RowBox[{"25", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "R"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["5", 
         RowBox[{"3", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "R"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["5", 
         RowBox[{"3", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["25", 
         RowBox[{"44", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["91", 
         RowBox[{"66", " ", "R"}]]}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8026639373415947`*^9, 3.802664149596006*^9, 
  3.8026645535936127`*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"73363abd-4022-4483-a513-16a095022a5c"]
}, Open  ]],

Cell["", "Text",
 CellChangeTimes->{{3.8026639684117947`*^9, 
  3.802663985514777*^9}},ExpressionUUID->"ebc3853e-526b-48a5-81bb-\
7a9f30466437"],

Cell["\<\
The 16 stationnary RHF solutions yields 3  differents Fockian which are all \
diagonal.\
\>", "Text",
 CellChangeTimes->{{3.802664154376062*^9, 
  3.8026642028862133`*^9}},ExpressionUUID->"e3b49f5d-3aad-49ed-a3c1-\
faf6e92e1b06"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        FractionBox["1", "R"], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["R", "2"]], "+", 
         FractionBox["5", 
          RowBox[{"3", " ", "R"}]]}]}], "}"}]}], "}"}], "//", "MatrixForm"}], 
   ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        FractionBox["5", 
         RowBox[{"3", " ", "R"}]], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["R", "2"]], "+", 
         FractionBox["29", 
          RowBox[{"25", " ", "R"}]]}]}], "}"}]}], "}"}], "//", "MatrixForm"}],
    ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         FractionBox["25", 
          RowBox[{"44", " ", 
           SuperscriptBox["R", "2"]}]], "+", 
         FractionBox["91", 
          RowBox[{"66", " ", "R"}]]}], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         FractionBox["25", 
          RowBox[{"44", " ", 
           SuperscriptBox["R", "2"]}]], "+", 
         FractionBox["91", 
          RowBox[{"66", " ", "R"}]]}]}], "}"}]}], "}"}], "//", 
    "MatrixForm"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.80266421123381*^9, 3.802664253037462*^9}, {
  3.802664325564295*^9, 3.8026643281700172`*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"5197a90f-f38e-4136-83da-21ce5f4572fd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        FractionBox["1", "R"], "0"},
       {"0", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["R", "2"]], "+", 
         FractionBox["5", 
          RowBox[{"3", " ", "R"}]]}]}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        FractionBox["5", 
         RowBox[{"3", " ", "R"}]], "0"},
       {"0", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["R", "2"]], "+", 
         FractionBox["29", 
          RowBox[{"25", " ", "R"}]]}]}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{
         FractionBox["25", 
          RowBox[{"44", " ", 
           SuperscriptBox["R", "2"]}]], "+", 
         FractionBox["91", 
          RowBox[{"66", " ", "R"}]]}], "0"},
       {"0", 
        RowBox[{
         FractionBox["25", 
          RowBox[{"44", " ", 
           SuperscriptBox["R", "2"]}]], "+", 
         FractionBox["91", 
          RowBox[{"66", " ", "R"}]]}]}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], "}"}]], "Output",
 CellChangeTimes->{3.8026643287561083`*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"3bacbe2a-e9be-448c-af54-b21efa2bf2c1"]
}, Open  ]],

Cell[TextData[{
 "The first solution corresponds to a density matrix spatially symmetric \
where the two electrons are in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["Y", "0"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "6830545c-4e21-4243-864e-626cbedbd134"],
 " and the second to a density matrix spatially symmetric where the two \
electrons are in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["Y", "1"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "e5920b7c-1248-4d1a-88b4-fc269923b89c"],
 ". The last solution corresponds to the symmetry broken RHF solution. In the \
sb-RHF solution the two orbitals are degenerate."
}], "Text",
 CellChangeTimes->{{3.802664422144541*^9, 3.8026644610619087`*^9}, {
  3.802664576888208*^9, 3.8026646364532623`*^9}, {3.8026647086489353`*^9, 
  3.802664764513528*^9}},ExpressionUUID->"3d90d84f-877a-4e43-b9c0-\
1030bf3f0df5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"x", ",", "x"}]], 
      RowBox[{"EHF", "[", 
       RowBox[{"R", ",", "1"}], "]"}]}], ",", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"y", ",", "y"}]], 
      RowBox[{"EHF", "[", 
       RowBox[{"R", ",", "1"}], "]"}]}]}], "}"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        FractionBox["\[Pi]", "2"]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{
             RowBox[{"-", "75"}], "+", 
             RowBox[{"38", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{"3", "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{
             RowBox[{"-", "75"}], "+", 
             RowBox[{"38", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{"3", "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}]}], "}"}]}], "}"}]}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.802664848452889*^9, 3.802664927591845*^9}, {
   3.802664979894013*^9, 3.8026649846265697`*^9}, {3.802665074034309*^9, 
   3.802665076675661*^9}, {3.802665278927999*^9, 3.802665320971797*^9}, 
   3.802665390572104*^9},
 CellLabel->"In[34]:=",ExpressionUUID->"6810a691-9e34-44be-88e5-257f5a8c1ac6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["2", 
      SuperscriptBox["R", "2"]], ",", 
     FractionBox["2", 
      SuperscriptBox["R", "2"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"50", "+", 
        RowBox[{"8", " ", "R"}]}], 
       RowBox[{"25", " ", 
        SuperscriptBox["R", "2"]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"50", "+", 
        RowBox[{"8", " ", "R"}]}], 
       RowBox[{"25", " ", 
        SuperscriptBox["R", "2"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["4", 
       RowBox[{"3", " ", "R"}]]}], ",", 
     RowBox[{"-", 
      FractionBox["4", 
       RowBox[{"3", " ", "R"}]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8026650769642563`*^9, {3.8026652797151737`*^9, 3.802665321969314*^9}, 
   3.802665390969667*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"f4a0ea68-29b7-4b88-8111-587d0e775312"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"50", "+", 
       RowBox[{"8", " ", "R"}]}], 
      RowBox[{"25", " ", 
       SuperscriptBox["R", "2"]}]]}], "==", "0"}], ",", "R"}], "]"}]], "Input",\

 CellChangeTimes->{{3.8026652169340067`*^9, 3.80266523728368*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"5860bde6-0c0c-4201-8a77-3e9ee0d2ed2f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"R", "\[Rule]", 
    RowBox[{"-", 
     FractionBox["25", "4"]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.802665232446504*^9, 3.802665237742845*^9}},
 CellLabel->"Out[28]=",ExpressionUUID->"0bba0f28-b669-493b-8c39-a3d7c1476497"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "R"], ",", 
     FractionBox["5", 
      RowBox[{"3", "R"}]], ",", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["R", "2"]], "+", 
      FractionBox["5", 
       RowBox[{"3", " ", "R"}]]}], ",", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["R", "2"]], "+", 
      FractionBox["29", 
       RowBox[{"25", " ", "R"}]]}], ",", 
     RowBox[{
      FractionBox["25", 
       RowBox[{"44", " ", 
        SuperscriptBox["R", "2"]}]], "+", 
      FractionBox["91", 
       RowBox[{"66", " ", "R"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<RHF_GS_min\>\"", ",", "\"\<RHF_GS_max\>\"", ",", 
      "\"\<RHF_ES_min\>\"", ",", "\"\<RHF_ES_max\>\"", ",", 
      "\"\<sb_RHF\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8026666647017097`*^9, 3.802666668731872*^9}},
 CellLabel->"In[51]:=",ExpressionUUID->"9a6badb7-ed47-40b0-8085-24c5bc98241e"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVlXk8FHgDxsc15EpMdygiqeRMB61SLWs3KoQoEb1EqZVElLYoerOpHLGL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          "]], 
         LineBox[CompressedData["
1:eJwVkXk0FPoDxcc69qyV0YaQ6qk8eULdb1IpVELWUNKipDyhpOTZSagIqahE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          "]]}, 
        Annotation[#, "Charting`Private`Tag$22076#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVx3k8FHgfwPExjHHFYDokZGYJlStXGTZFoRJLosid2MhdWRRPRTq0ZDKt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          "]], 
         LineBox[CompressedData["
1:eJwVynk81IkbwPExjK9zcrYiIaUtld1sheh5opDocKUSdtV2Sis5Em2lcWYl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          "]]}, 
        Annotation[#, "Charting`Private`Tag$22076#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV1nk0VesbB3BkTkVRaDJmJiLdxDmluZuklBQpmgwlpcGQI5FUQpJUhsqQ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          "]], 
         LineBox[CompressedData["
1:eJwVVWk81AsbnRnG3x7TTFmS6FpaLpVyXbo9j4nK1kIkISmRSM21hUi/skRe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          "]]}, 
        Annotation[#, "Charting`Private`Tag$22076#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV13c8ld8fAPBLZpkZoWFFskdC6LkqZVRkfcmMQnbDiIyKCEnLSkZFQmRE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          "]], 
         LineBox[CompressedData["
1:eJwVVns01PsencH4ERHjNZSiizq9nFPJa/l8vfIMHc+kkki3kLxDR4QoyUUe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          "]]}, Annotation[#, "Charting`Private`Tag$22076#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVlnk0VW0bxiVDSjI0GCNTeFWSg0LnoEmlVFSvSioVQlFKKqmQKEko8pJI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          "]], 
         LineBox[CompressedData["
1:eJwVkGs41Akbh800/J3PLKOVw6LdrFqWFdXzkEqoNqfaorVtqq2kLCo5Vo5J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          "]]}, 
        Annotation[#, 
         "Charting`Private`Tag$22076#5"]& ], {}}, {{}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{-3, 3}, {-5.097790999939638, 6.69737696313212}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"RHF_GS_min\"", "\"RHF_GS_max\"", "\"RHF_ES_min\"", "\"RHF_ES_max\"", 
       "\"sb_RHF\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.560181`", ",", "0.691569`", ",", "0.194885`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.922526`", ",", "0.385626`", ",", "0.209179`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.3523253333333333, 0.3137493333333333, 
                    0.46756733333333333`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.528488`", ",", "0.470624`", ",", "0.701351`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.528488, 0.470624, 0.701351]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.528488, 0.470624, 0.701351], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.802666669492197*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"26ac9f7a-2ee6-49e0-b0ac-59e073e25c7d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "R"], ",", 
     FractionBox["5", 
      RowBox[{"3", "R"}]], ",", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["R", "2"]], "+", 
      FractionBox["5", 
       RowBox[{"3", " ", "R"}]]}], ",", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["R", "2"]], "+", 
      FractionBox["29", 
       RowBox[{"25", " ", "R"}]]}], ",", 
     RowBox[{
      FractionBox["25", 
       RowBox[{"44", " ", 
        SuperscriptBox["R", "2"]}]], "+", 
      FractionBox["91", 
       RowBox[{"66", " ", "R"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1.5", ",", "2.5"}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<RHF_GS_min\>\"", ",", "\"\<RHF_GS_max\>\"", ",", 
      "\"\<RHF_ES_min\>\"", ",", "\"\<RHF_ES_max\>\"", ",", 
      "\"\<sb_RHF\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8026647943669777`*^9, 3.80266479764023*^9}, {
  3.8026654022411537`*^9, 3.802665430892762*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"8b8bc894-1909-4f82-8fc2-be6f3932aa91"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVzns01GkcBvDfzLtNNSSVTujiUoqisrZC+L4NlT079sg2q1pbUSMbqXXp
ZmOtSym3JaQMicRM0z2XVrvVlruWcPSbm7maKNkizRhjdvaP5zzn88dzzmMX
djSITSUIIsCY//urY6dnEIQGauuPB7JYKqikfOZsoWjgfWzmb5t2qsAiP3Zj
ClUDnOTzr6y+U8HYw6hDtBka8PvHuUMSqIJ7ur2tpnQN8GlnHQ4zVbD+rG+W
lYUGPO4nRKX7qmBNqelCN0cNVEerV/e5qsC+o3RFeKAGvKu1EW1mKminn0nL
uaGBCZ477HquBO1cpedHjQaCj77/kvurEhaosn0a/bVQXj57agKU8KZkLOXr
Mi2EHgjNytEpgLFYttT8Xy0wa5wKdj5WQPAv57TF2ydBPZjflJ+ggN382OUX
OJMwr3NRPddLAdJKdfnDkUnwWSimhyMF2CctDKvw00Gtv9WK1iY5DNl0HG8r
0EHvMee5mTlyKMltInepdKBQ9dtz9siBrjydyN08BVvvOz9OspeDXl93YkPm
FLxPv1LFGpUBb/LWvRTFFKyJv0yzb5DBtuahzR4eelDMpDmuSpMBew/fyjFD
D1EB3u8aWTLAXas9BAN6CPPzyo9eLoMyU1f+i/XTkJEfNJL4SQqP1nwIizs3
Da355rvan0vhqfWn8POSadghZb+dWSiFgK7kv8i1BpjjEp8eGCmFixEtu9+l
GWB+UKfbhLcU9jcX+bv3G+CWv7n2jIUUTBP6nsUvIHDTxOoiX3IAXiAv6l0f
Ajt1ZQmSUwfg6ejg21mHCEyYmZVObRwA687o48/yCHxlsNrnmlICP+VZVt9+
TOCeyC6PyAIJ6B7RUhtUBG75oWHHGFMCw73dhMM8Ci5eVD8uMohhSZBsFd+D
ggVi+fDWBjH41c2fiAilYLdNN4OD4sXQNseOnZ5Jwd3s9DMfncWQ1xyb+OQB
Bb/2pufUDIugPqbCPURKwbz9vltsKkVgm7yIYzGbimlzAgbiDogg8QS/mnCl
YttTPiaODiLw3GfL+jaEilcWj/Gb5EJw5/bz6lOp+McVln8MXxfCxcHIitQ7
VJzVVRFjyxbCIN2ekSqkYruQVq+alUJIyFty4SpC2NOXaAkbEcARk/G4ZesQ
lhTkq7+/I4Br6rmzG4IRzr7Oyw08KYBOXoDf2SSE/6SLb21jCIAVGmFbx0XY
//cWc84sAdiebq5CPQh3Fzq63u0hIfiQ3aU6o0v9RO1Nr0jI3pmQEdmLsHDU
5YSom4SpteuievoQ5rpUGmZ2kUAqCl0rXiNcJ+b27+sgIS8gvJEhQTjpcuG1
+S9IQHYzXiUPIZz79mpRai0Jnmb7/t4wjPCpZzcZJQ9JiNHVPxgyOvDcsun7
D0iQ9kUV7Xhn/D/qXKW4R0Lj+d4Qu1GE6eXPH/neJiFuvEL9ZBzhMhQyTqsm
gSfTv477hPCHLz5X2twgQf4yuM1xAuFopojtXkVCYI0JP/czwoyORMvDlSS4
7I2N2T+J8NKfx/DLqyQc/KbzgIXOuE+5E6suI6HEfRWrxWiZDbeWMJq+QLhp
vR5hByvmETcOCVuIDU5Ko63pH6TMEhJOjmRbX5pG+Aiv/WD4FRJuC96YMA0I
Z2wXaJIukzDYzNAbjLZ0WswpLibhP79yXvA=
          "]]}, 
        Annotation[#, "Charting`Private`Tag$15002#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVx38803kcwPHv9kk/cPTD7kqu0PWo9Eh5SEbq/TH6oSgXi+SQCoVSkwpx
ZfJbO5d+XaLWlbhd8VBbHkI5UdFNKMuDwr77gbEVmc3sdn+8Hq/H0yb8+J7D
VIIgfAz9//VxiUYEoYZrnoJYqyYV3KVMFLlT1KB8vJRh/1IFFr+zNqRR1YBi
WGtxowq+Po6JnGmkBjOq0P9QgwoqtSGvTI3VwElXvuLVqWBdhkfeIgs1BNEi
g7YIVLD6linNcaUa8hy+n7z4QAW2Lbd+ivBVQ8+TxAC/XBW8MT6Xfum+GnZd
mpHttUsFk+Zi1y9qNTQHn7AboKlgAZm/uWb7JARXVCarPylBdvNrmlfxJLS9
SyqZuKcExuK+H+cqJ6GWf6dtMUsJAcmZk9e3aaC+UJjo66aEfTzWspwiDYjt
jlwfmKWEz3eltx8rNDD/bWON/6NRsE2lhXM9tSBaZue2e+coyJe2JLwu1IJp
zVjD5tERuMl5KQoktfDvqmdio6sjYCxOTCnbOAWszmJOqssI6HT80065U0Df
gKJdxAoo1/xdmTYwBdsb9oYNZClga5N8o4uLDoT8Koa7owIOB/EWrczSQcj7
uZ9cxcOAhXYuHz/pQH3i0Hg4ZxiKTR14jeumgVOSldPuMQzVq1Xh8ZnTsPtb
3KbSL0Pw3HI8Irt3GhzePOjh3x0CH+H5OpG9HurHY50u/jIEl6Oa9w2n66E5
s7x8dN4QhDVd3U7/oAfbs3FjbS2DYJrU+eLUAgJrbSd14dmD0IjcqBWbCXxm
TULOc49BeD4qGZodSWD/JyaiFWgQLFuPJbwoIPD7o87rM2rlcKRgYenDZwRO
n5FmxE6Wg7Z6JvspSeDkluOLrLEcBjvaiOXzKNi/duRNv14GVnv6VvBcKDjn
4Pzr5o0y8OTP/xZ1gIKZaeZex3Nl8Po7m8MXcynYvuxG1FJfGRQ0sVLqqyh4
fW/P7f6FMhCc5NKDP1OweLnAxLJXCtbnfyiymEPF3dm06g2lUkg5zSslHKh4
a3XIHO94KbiGWjN3BVNxsX6HROMmBXrZh3IBm4q5LPkfHsZSuCyJ5rIfUXFC
V0/Vlg4JSIxtGexuKn7Zcr/SuUQCSQVWOSUI4Zl0Yio5TgKxJmPxS9YiPDCl
qS/aJIE7UvM5TwMQ9g4VtyrMJNBa7uOZkYrwLUfBb2QfCcwDUdb8MoRrlt2n
d1WQYJ3YdA+1Izyj/bZfbToJAZE21/gGs/Od9Ro2Cfn+SVnRHQj3b7sncDZ4
yn5tTHsnwgLhbGbFBRJEA1ccuF0ILzR76vhnKgkFPhE1jF6E6349l3HpLAnI
xujdeTnC6mP7U47FkuBqFtrgNIjw3Duu/X/FkHBSK6iSG8yw+sdvKJqEz50x
V38eRnjCShgadZSEmuyOYJtRhLO6uYsPRpIQP8aV1o8hHBQ4Yb3/AAnlfbqu
+HGE40WtITfCSOh/G/B65TeEZxU6l4lCSfB9YMLjTCCcp689EhhCwpoQ1skw
DcLDmady9u4n4dDO1oMWWoS9Gp45XQki4SZ9BbPZYLfGPEXnPhKMF3Q7r9Mh
vONoXTozkAR3wmmV2GCa45KIwgASzijyLa9NI9xtpvfr3EvCw48yE289wl85
YbtpBkuaGDq9wTJv90Amk4T/AG6FZJI=
          "]]}, 
        Annotation[#, "Charting`Private`Tag$15002#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVzn8803kcB/Dv9k21UepSJFe26pHqDhOdX+f9ITlduVyP3CJXWakuuisb
eVDrPMiP1K5D4a5IuIRZqW5arqIL/eBc1kIl8qN8bDHb+DKz2/3xerwez8fr
nxeL99O2SDpBEEGm/N+uRxLMCIKCzcXnOaJeCkpo45d8aRTY11Qn9fRQYJXN
X59MpyC57cpst24KNLejD8w0o2BJbJvs9WsKqvW7HlswKZi1NUziqKDAOW3D
2cVWFOhqV7a+bqJgbYHFwnUOFPg0HC6PqKKA/axgxf5gCp4XReeaJ1DwlHni
1C9XKTD2pszdaU7BhGWf5yhFwUuZwjX46jgs6Bf51AZOQN1clyaXwHH4cFGT
vKlwAmQXKq9y+sbAb0nPp/NGJsDby5X9Z8YYcI+nT+R/NQlU/zxFwZoxCBXz
l2demgTum9x4dqsOukveF91WTQK9l7HcSagD9smFvGJ/Pdi0HOK8W6WDwWXP
4p6c18PxqnzW5Q4tXDzX0LGjXw8CeVSRXqQFZl+CsNxrCmbPOOrlibRgMEiP
uZ2ZgiLXtZ51lAYqJquqk3un4M3N2C17xRoIaBz08vAwALOLHxsTqYHIMPFi
hwwDxDkyr9mt0ABqXePR+dYA4m2/KazfjkKhBUf8yHkaPpO7qL67PAqytWqe
IH0aar6sx4t2jUKdrW7/6S7T7lOWf3/pKAS1Jt3vcDSCICFv67J+NeQcbApV
njLC+s31SscyNexpzA10f2mEBiM/teqIGiwSX9THLiBQlo2vb7qXGh6R3vQb
PgTiSeQt3qQa6oYHhmYfIBDDPRSP/DMCts0/xtVnEUhyl/O8NH8EfsiyKZP8
RaC0X7eEFUSOgF42M+VOP4Es2eDmvH4EsPxfYuV8GmoK5joNkiNgt61nldiD
hhp31PMtK4fBX/rJ2MEIGrr3NJU1Y/swPJnDikw9Q0MKMMw/O/YRshr5wge3
aMhCs9HMq+gj1MQUu4d301COcJ+DLOAj2CdZX7Ji0JExQs+epVWB8Ji4jODQ
0aFFJ7h5JSrw3G0f8k04HaVGxQvdg1XgXv6yoiaFjsJirt9cTKogZyCqOOU6
HUls4r+GG0oYYLL9Ul7RUVt+2aMsnhISs+wyL5MkanIK/b7UVgmHzbWCpU4k
4jcFTK9rGYIr7y0Zd7gk6pqvLIT0IWiuCPJPO0miZeHN+Vr/IQiJOGgvLScR
nf/q9x0GDPYJjX+QbSRqYEyUNt/FwD3AypOazPDfWVshwyDanpgRJSfRrZWl
OOMOhilHp+i2FySyDuwTBUgxdPRe4BS3k6iPuK97UI0hK2h/rV8XidySd3vK
rmEgWWbPkwZJxFQ4Zt7LxeA5d/dDN0yijUfVeYUXMMToa24NmmzdCfd+Po+h
+0V07rdKEv0tFWzdkI2h9rQ8nDVMousuw5mPRRgE2uL3D7Smf3biQ52nMFT0
GNoFOhJJCtqHa1MwvGvhPnEYI5FMwjtTmIwh+Jq5+Nw4iTq808wjkzB8vosf
s2eSRANhD1nq4xj2bW7ea6UnUUhpToQ8EcNF91UhTSaHM6pqpAkYmAtefeFs
IBFSiiuF8Rh8CbfVfSZ7tIk28Y5hiFeJbPOmTX9KKg0b4zBIOj+YbzGSSJE9
4/HqWAwDjX4Go8ke7dkVcwQY/gN8l2F+
          "]]}, 
        Annotation[#, "Charting`Private`Tag$15002#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVx38803kcwPHv9smPhvxaXZyEOPQLV2pI7w9Jq86dc6EfHjHZUjr1yFKR
IcqvJe1KdQ+kI3Xc+qUeKD2oO82FHhxRuVLtu82GjJVmP7jdH6/H6/F0jj8Y
waYSBBFm6P+vPpRmRBBqcD+J8uacUEE15Ut5EEUN/ja89ZVpKqD/krImh6qG
/nkMt3XHVaC6f2CvsZEa3DihWdxUFdzV7v7bnKaG5vqeJNkhFXjnbThjR1cD
e1WvVT9bBcsqzOev8lDDzn1Ht/X/oAKXzgpXTrgaoi7rX8a5qqCDlnHq7HU1
bIzJYPHbJ2HakvSfVKthUf3Tjpojk2ArKV7fzJyGwqud8WPfTMJwmSpn85Vp
SFabZOC+CQj++v0iK+U0mH2mdecXTED0ifzpy5s0sGGwqNcuYAJ2CFOWFJVr
IMRVmHhGqYR31bKr98c0sDV/yMFBqASXzPnxVSFaYAWaOi7lKEG+uDP12QUt
2LdlpUrdlFBW8vTVdokWVosamyJ7xoFGpvFqA3RwK6+QHRQ+Dnp9w1Ffvg4+
5O1oDRj8CHWam3dzxDpY7EKsmYr9CKEieYCfnx7mXK8V7leMAXun0M6jQA9k
R41jW+YY4O6lfq+H9DDJ/ymbYTkGV8x9hG3eM0C3DJXpbozCg2UT8dz8GfjV
xLTDM3AUHtt/5hS+nQEOP+Hm8v4RCOvObnm1chaO0LrrS46NwPnE9h2jp2bh
plUSr3b+CMSJLjIZA7OwYH/hhT8eKsA8/cWTI7YEXhyEPAVsBbShddQ76wms
qG405tIU8HhcOmK6l8AsYXp9ZoMc7LuSU58ICMwUhLOexsphn2DhjVuPCNxa
ndnRbiYH7QPj3CYJgW3i4iKYLcOg6Osh3KwpeFPW82tBycPgEPHeXehHwS12
U01xrsMQ0mAzlcii4D3nHjP5b2TwzMKZfZpPwaYF3pP7BTIQiFJ4rfcMnoA7
4jAZNB6uYsS8o+DiNyWXg4xk4JT9VTl9LhWPJ1rsUj6RAu+o8AbhQ8UHjwd+
3JwjBf9Yp8jvY6hYXMm3fghSYNQO1DXmUvFf62K/NaFK4bw0qSr3NhUXtZPV
pa0SkNJcgnMHqXiBAyvgUbYE0gUORZUI4WSOf3gEUwI/m33iOnohvFRhTtlu
JoHfZJZzm6IRPm7BMLnQS0JXXVhIXibCmdWppZpyEiJZiU4NtQgv5FSs1iSQ
4JQmqkG9CF9axIsd8CYheq/zpQaDOyfWDii9SCjell6Q1IewpqUqnmawbqXX
gd4XCMdl5N0LXEHCK3GpT9VLhHPU/iHXPEkQhHGag98iXOnoZX3MhQTkbPRP
thxhu6gt4cvpJPjPi/3TV4Ewp6bIj2lLwmFt4z25wZFbfNYk2JDw7sWBiz+O
Ilw0eWVfmRUJzYV9Mc7jCNtWihotLEjgfqqStX5CuFTgMaUyIqHuvf4l9zPC
a7vO0q0N/vA8+pnHFMI2jr6hK+eQEP67mbDkC8LnsrzFiVQSVuxOORynQdi4
5zoamhFDwtauPXQtwvM2PHqo04uhjOEe2W4wr0d/2t5gmu3gWm89wrquqago
rRiCCF9P0mCPk7W7uBoxHBsrtr80gzBlKDNFMC2GW6+Hzb6bRbgwn1txWy0G
qShYP2uw+5LT/z7/Iob/AAgdToU=
          "]]}, 
        Annotation[#, "Charting`Private`Tag$15002#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVzHk81Hkcx/HfzG+zmVhpRIdao5SjJVuEaj7fZDcqNiIRcnTokWKHjOh4
WGxUO+yUXOmgS5pNPXKksUg1sumh6OFoK8d3TueMoxljzM7+8X68Hs9/3ozI
WL+DVIIgvHX7v+vjkucQhBIaIsxOBdcr4Bbla/EWihKG8mPW2/ytAJNL8c5p
VCXY+IcuUPIVMF4Zc1hvjhK2O0wxr9Qq4LE67LUBTQmYvy24o1IBa89t/WOx
iRJeF6ZeCnygALtrBgvXWSuhqj+s72SBAizfXFt5aJcStJl7ktYkKOAf2umM
7LtKyPUSBThZKUBlhN0USiUkdUd8avgkB7qQw+R7qkC2B7fVFchBcnU8zeu6
CthaVecqPzm4L+1bNn9MBd3yUHMfYzkEnspUFWybhha7yQCT1jEI4sWvuFA8
DYqYfVkLL45B7y3xzcrhaeiaQabWvmNgeXZhZKmHGmIrKvT16WMg/f5NYkuu
GsIGw2q8Kkfhas6r7r1CNTCbOqeLvEaBhpPP3N84A+eJo0b9nSOg0VSznS7O
gA3d7Rtu3AiUT//1OG1gBuLa+EEZ5Aj8LJBudHXVgId9mcqvaBgOBvMWW2dp
wH/cs7dw0zCgNlvXni8acD6QlRPfNQTXDRx5L9fOwhorvQnv00NQayePTMic
hfGM2FMa8yFoXDJ56PznWZhv+va3dw2D4N2WWt9tr4VVhoW/DsQMwuXo5qCh
DC1IagwcvjMZhHBBnqdLpxZ6vs2YpTfJwCDlw/MTdAIlWe9RsU/I4CW5ifqI
SaBjPrvyflwhg8ZR0eDcwwQqtjJ2seuSwpLW44nPuQRqiR2RVWRK4Qh30b2H
dQRaynn/LHGTFNS1eulPhQRCTUa+g1MSkHW8I6yMKehcTMjulTwJmPv1rea5
UlCg5dy0piMS8KheMBUdQUGv/j2+wdhGAi2GjIO/X6SgYDPBVAAWA1cQf6bh
CQXd8GVOXbgthhpWqUtILwXN72D040gxWKSaFZvoU1EuW3tHbiWGM2zePcKR
ip4MRe8IGRSB236LAJ8QKirOFtw05YnA5X5neU06FS0Of+DJSBDBZdHR0vQK
Kvrcy9xcskEEIpqle/pHKlpnf3wZSyOEFK75hRskicqkDxydm4VwbN5EwnIH
Eg1ots8tyBZCidhI/2kgiarbE+0b9wmhtdzb49xZEi2PXrm5x0YIARHRFtX3
SWTLempbPYHBIllwh2zX/ZnwOQYvMAQeZuRX65w0KXd1asLA8U/JOtpBoqio
3VOhzzHM2DvEtH8gkVlLTsnDBgzdA1ccS7tIxDasa95dh4HrfYjv/plEs82m
269XYSAZc96nSkm0g1W7YGsZBrfv9jc5yUhUuTz5y7F7GFjqmidSnasMrery
72Lo/RCT5ztEIlr9+vKR2xj45ztCGKMk0ntH+hWVYEiYKBU3TJCI/vJW89ci
DOV9mq6ESRL55tuWrtC5/21gi/UUidTaFM4vhRh2lc3j5Xwl0Yvyk3l38zH8
EBbPCp8mUVx4GWtvLoYDO1qjTNQkYjb4t6dfxnDVZXVAs8710888Hl3CQKN/
3LBWQ6JG66ogGhfDFsLJBuvMdvxJ4/wnhqRhzpL8WRL5QOajqBwMD3sk83Zq
SXQj9HRiTjYGkcBdo9V5Ub7lzjoOhv8AeltggQ==
          "]]}, 
        Annotation[#, "Charting`Private`Tag$15002#5"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {1.5, 0.40000000326530616`}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {1.5, 0.40000000326530616`}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{1.5, 2.5}, {0.40000000326530616`, 1.5555555283446718`}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"RHF_GS_min\"", "\"RHF_GS_max\"", "\"RHF_ES_min\"", "\"RHF_ES_max\"", 
       "\"sb_RHF\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.560181`", ",", "0.691569`", ",", "0.194885`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.922526`", ",", "0.385626`", ",", "0.209179`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.3523253333333333, 0.3137493333333333, 
                    0.46756733333333333`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.528488`", ",", "0.470624`", ",", "0.701351`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.528488, 0.470624, 0.701351]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.528488, 0.470624, 0.701351], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.80266479254737*^9, 3.802664798076623*^9}, {
  3.802665403689989*^9, 3.802665431608905*^9}},
 CellLabel->"Out[37]=",ExpressionUUID->"bbc68235-4dbc-49c4-9812-3800209db685"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    FractionBox["5", 
     RowBox[{"3", " ", "R"}]], "==", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["R", "2"]], "+", 
     FractionBox["29", 
      RowBox[{"25", " ", "R"}]]}]}], ",", "R"}], "]"}]], "Input",
 CellChangeTimes->{{3.802665520994482*^9, 3.802665547566701*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"0d8a6035-f32d-4793-b1ca-f87b3610e89e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"R", "\[Rule]", 
    FractionBox["75", "38"]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.8026655320548964`*^9, 3.802665548060293*^9}},
 CellLabel->"Out[40]=",ExpressionUUID->"ad0d2235-147f-4518-87c1-4dd62e352642"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "R"], ",", 
     FractionBox["5", 
      RowBox[{"3", "R"}]], ",", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["R", "2"]], "+", 
      FractionBox["5", 
       RowBox[{"3", " ", "R"}]]}], ",", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["R", "2"]], "+", 
      FractionBox["29", 
       RowBox[{"25", " ", "R"}]]}], ",", 
     RowBox[{
      FractionBox["25", 
       RowBox[{"44", " ", 
        SuperscriptBox["R", "2"]}]], "+", 
      FractionBox["91", 
       RowBox[{"66", " ", "R"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "0", ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<RHF_GS_min\>\"", ",", "\"\<RHF_GS_max\>\"", ",", 
      "\"\<RHF_ES_min\>\"", ",", "\"\<RHF_ES_max\>\"", ",", 
      "\"\<sb_RHF\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.802665477801262*^9, 3.802665483930757*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"fcf7baa2-6f77-4232-a400-15762d5e1fd2"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVxX1cC3gAB+DZZivqE8PlNXIp0gtyKafOO3nLUZaIpDddNYkQssMUHZUK
eSkneqFXlV6c+/5I3NVKL6Y3ta1tTSW1rraZbHf3x/N5TH04O/yoFArF7T//
X8j+S6XTMYnLyvS97u4CXD5jmDhLyyQRR+67UNkC+KTvsPlxlEks3zIi8z0E
YA188I1QM0nSbeeH4/YKcPSiouHTIJMo7s23eOUjgEPJ9JxWMZPcEcu71xwW
AKwQ76JKJtnTteBNRKwAtbUT//aPZpIDQcEPcl8KUM95VZpFZxKvjSuE653f
w+BjdmbSZQaJ+Tyr8PnT9/DLWnBfxmIQA+5PLNniZmQksSomJowlvIvXllx8
3ozZbJsmufFYkvh74BHpuhZw1xXppyTRSfzyB0EvRS3QnmrclD+JTny0t6lc
bitKYsyucG7TyPGm/cXdM9uw84Xw07hpNMIruFW36G0bLOtrt25PoxLKifYU
TlQ7TCx2lWssqMTeslxgZvcBX7I3rOZmjCGmkVURVGoHDGnB/HzrMUS2JauG
XtcBvZgv4RWPKMRkU0Hj0rJOmLqbmltaUkjq8JnH0TlCSAdVT6J9dSjdf2aO
k6sIbnFn3cK8tajmp1SJ20SwbwtW54V8w6WWnro+PzG6T1s13/cfhdqor9SI
2YWG/Dk13r5f4clbE8As7IJ1XOSLI+EaLKGxDTfukcDjdcbQ8tAv2LbW5NmM
uVIMZzuYsyPVcIjzul3SK0XNLF2oU6wKipqBEFPIENZzY6g1Wgl13pbJUeXd
iDlw/UR18gjm5SRUupXJEbI4wDEsbhh7NeSgrvsjriQEG3Vd+QfzlsqlOpte
zE5tlmfcHUJ1jo1Iwu3DWeqUr6YpCgyUca6On9qP7ZPKJigeDiKR0dSv/+Iz
KgJnH5/MGYDv89R3lS6DCPMMX110qB+02MVf1wcqMP7hNZbmYh+Y5svnXUoZ
wqq0XR65p3owLtmecdp4GJ5Dsvt6iXIIb1T1DpaOYP67cu/fYuUwCRs83/Ln
CJQlV0wmXJDjtNr/3KuqESSe/OGW8TE5ts4xINlNI+BTeAnmbDlSox1KsgdG
4Gxkxl07Qw77m44/n5+vxFwrHy9uejfqjJNq/7irRI9fp7G6SIaNdQ1zd99Q
IaItJrr1sQyt9vtbbO+pQHW1U1Wky/Ay4KOtYbYKMx1i3p9JlOFko7irvUKF
beOWJNPCZdCPSbaq7lShOI/HMloig+Mq5+8UFmqcVVkZmhdIwfL6orkHNaZc
OkV1y5EgX/64MJKhAWOhI4s8kGDBmqmiCxM0UPKVplZ3JUi58Gv99ekavJ9w
ZBX9qgS1k/bNaLTR4PrNQG4xRwLl+TaPTLYGU7PctZPtJLDtp6W9e6TBzDe2
GkF5F5bV9zZGsb/CbKxUwX4jhi9PPyiYP4omxxNFphCDZ+bSjtZRnAs1ONb3
VAy9twGZs+WjEDYvVUdliNHxZEUynfoNtx7xtA95YlRSFxX6OXyD0XaL8cNr
xEj3bMhIyvwGza0gs3giglcHLdsyXoust1rZ7jIRVAbLAq3TtGDTEzO/LxDB
epdrv3OeFsUhzyxL00SoDn1x7ypfC85Kg8WdUSJsvrN0hkRfB6ks18nKSYQ4
R1v/o9E6pB7oyo0PF2Ldav6isA0Uopu0r/HwQSHKezfr1blSiPfrVuX2nUJM
o+OUnQeFzF3Y8NNEOyFEDOkvUw9RSMYwGhKGOuGepP20OZZC8qLvjlwL60Rf
aEi+XwOFINfDKZnTAfr8dj++7xjyuKpFcTqoA43TLSrrA8aQfwHJmPZs
          "]]}, 
        Annotation[#, "Charting`Private`Tag$15426#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwB0QIu/SFib1JlAgAAACwAAAACAAAAsVfI9///B8A9YN13HMfhv4p9DZMd
/gfAYl8H6IHI4b9io1IuO/wHwPgBW5DnyeG/Eu/cZHb4B8BQLLSJs8zhv3SG
8dHs8AfAdNuhIE7S4b84tRqs2eEHwFiRFuuN3eG/vxJtYLPDB8BM56JQOPTh
v83NEclmhwfAplhaXjsi4r/Qb8S3qAQHwPjmXA87ieK/DOipp5SKBsBx8ZgT
nu3iv2WoKaLlEgbACkCK5D5U47+mlBK6EZEFwMUaen+ayOO/H1cu0+cXBcBQ
MVdfPjrkv4BFswmZlATAJIYzrky75L/+e9JKrxMEwP1T16xqQOW/tYgkjW+b
A8CNhfpAwMLlv1PB3+wKGQPAxD3WVlNX5r8q0M1NUJ8CwADkNgBd6ea/HidW
ufonAsAto28H9H/nv/mpR0KApgHAxuX5Ylcs6L8NA2zMry0BwGiVYVRZ1ui/
CIj5c7qqAMAZkz1agZnpvyFVISYqKgDALqGTuRtl6r/k8Peyh2T/vzFKJja7
Luu/VI9/VHFg/r+mqlVJeBfsvzbabPiubf2/5WgwrjP/7L/mfCzXomb8v/Rv
Mt3EC+6/0a8gy2Bk+79A3sVWDCfvvy2PesFyc/q/qYLItWYh8L9YxqbyOm75
v0GO7hsXx/C/9Kk4Jld6+L8EongBQm7xv8sd/249i/e/n9RHhkYf8r9x6Zfy
2Yf2v86R6hDp7/K/iGGWeMqV9b/KZPmiRsTzv20xZzlxj/S/THvLfX/A9L+N
kWwP4o3zv3SrwD7V0fW/H57X56ad8r9T5SaQaOv2v38CFfshmfG/x8QHTLQ+
+L9QE7gQ8aXwvyUwhZvdoPm/umgfdxRv77+mO7O3myX7v3Fac0Kzae2/BT39
9yAD/b8LpZIS+obrvwvqYJPk//6/QZ9WWK176b/eJtivPL4AwOlekgXpjOi/
0honw9BnAcAsGIjF
          "]]}, 
        Annotation[#, "Charting`Private`Tag$15426#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV13lYTO0bB/BW7aUshWiRJMuLaEEm2csS2qS8SSq90aKUihalhahXkS1L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          "]]}, 
        Annotation[#, "Charting`Private`Tag$15426#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV13k8lN37B3ChSGQtFaEIpVV7/eqWnRRK2iSFyE5CsiVZ8gilvSTKQyr7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          "]]}, 
        Annotation[#, "Charting`Private`Tag$15426#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV13lYTO0fBvA2SohKWuglkVSWCKFMErK8iShrWihLuy1tkjaFQhJR0UuJ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          "]]}, 
        Annotation[#, "Charting`Private`Tag$15426#5"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{-3, 0}, {-2.17569115126694, 0.8402362019897942}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"RHF_GS_min\"", "\"RHF_GS_max\"", "\"RHF_ES_min\"", "\"RHF_ES_max\"", 
       "\"sb_RHF\""}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.560181`", ",", "0.691569`", ",", "0.194885`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.922526`", ",", "0.385626`", ",", "0.209179`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.3523253333333333, 0.3137493333333333, 
                    0.46756733333333333`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.528488`", ",", "0.470624`", ",", "0.701351`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.528488, 0.470624, 0.701351]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.528488, 0.470624, 0.701351], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.802665485022585*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"e38e86a5-c37d-49fe-b290-a6b33e450513"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    FractionBox["1", "R"], "==", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["R", "2"]], "+", 
     FractionBox["5", 
      RowBox[{"3", " ", "R"}]]}]}], ",", "R"}], "]"}]], "Input",
 CellChangeTimes->{{3.802665555155958*^9, 3.8026655739472303`*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"37a432a5-9212-4f69-bd4f-ee45ce14d63e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"R", "\[Rule]", 
    RowBox[{"-", 
     FractionBox["3", "2"]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.802665574842998*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"491e73c8-dfa7-4aa6-b488-9857bfe4c759"]
}, Open  ]],

Cell["\<\
The sb-RHF energy interacts with the minimized RHF for R<0 and the maximized \
RHF for R>0. For negative value of R there is a point at which the attraction \
of the sb-RHF will minimize the energy than the kinetical energy.  For \
positive value of lambda there is a point at which the repulsion of the sb \
RHF solution is bigger than the kinetical energy.\
\>", "Text",
 CellChangeTimes->{{3.802665631307365*^9, 
  3.802665821976782*^9}},ExpressionUUID->"76876f74-21ed-474a-9a9d-\
85f07d24750a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["UHF solutions", "Section",
 CellChangeTimes->{{3.802665981186164*^9, 
  3.80266598327061*^9}},ExpressionUUID->"afaead18-5e78-459a-ab9e-\
1f6826e79431"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"F\[Alpha]", "/.", "solUHF"}], "//", "FullSimplify"}], "//", 
  "Expand"}]], "Input",
 CellChangeTimes->{{3.802666070814342*^9, 3.802666071124333*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"ddc4bd4f-72ca-4be7-a6bf-141af9605a4f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "R"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["137", 
         RowBox[{"75", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "R"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["137", 
         RowBox[{"75", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["5", 
        RowBox[{"3", " ", "R"}]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["1", "R"]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["5", 
        RowBox[{"3", " ", "R"}]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["1", "R"]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["5", 
        RowBox[{"3", " ", "R"}]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["1", "R"]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["5", 
        RowBox[{"3", " ", "R"}]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["1", "R"]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "R"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["137", 
         RowBox[{"75", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "R"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["137", 
         RowBox[{"75", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["25", 
          RowBox[{"56", " ", 
           SuperscriptBox["R", "2"]}]]}], "+", 
        FractionBox["109", 
         RowBox[{"84", " ", "R"}]]}], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]], " ", 
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]]}], 
         RowBox[{"84", " ", 
          SuperscriptBox["R", "2"]}]]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]], " ", 
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]]}], 
         RowBox[{"84", " ", 
          SuperscriptBox["R", "2"]}]]}], ",", 
       RowBox[{
        FractionBox["75", 
         RowBox[{"56", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["121", 
         RowBox[{"84", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["25", 
          RowBox[{"56", " ", 
           SuperscriptBox["R", "2"]}]]}], "+", 
        FractionBox["109", 
         RowBox[{"84", " ", "R"}]]}], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]], " ", 
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]]}], 
         RowBox[{"84", " ", 
          SuperscriptBox["R", "2"]}]]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]], " ", 
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]]}], 
         RowBox[{"84", " ", 
          SuperscriptBox["R", "2"]}]]}], ",", 
       RowBox[{
        FractionBox["75", 
         RowBox[{"56", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["121", 
         RowBox[{"84", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["25", 
          RowBox[{"56", " ", 
           SuperscriptBox["R", "2"]}]]}], "+", 
        FractionBox["109", 
         RowBox[{"84", " ", "R"}]]}], ",", 
       FractionBox[
        RowBox[{"5", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"2", " ", "R"}]}]], " ", 
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]]}], 
        RowBox[{"84", " ", 
         SuperscriptBox["R", "2"]}]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"5", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"2", " ", "R"}]}]], " ", 
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]]}], 
        RowBox[{"84", " ", 
         SuperscriptBox["R", "2"]}]], ",", 
       RowBox[{
        FractionBox["75", 
         RowBox[{"56", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["121", 
         RowBox[{"84", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["25", 
          RowBox[{"56", " ", 
           SuperscriptBox["R", "2"]}]]}], "+", 
        FractionBox["109", 
         RowBox[{"84", " ", "R"}]]}], ",", 
       FractionBox[
        RowBox[{"5", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"2", " ", "R"}]}]], " ", 
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]]}], 
        RowBox[{"84", " ", 
         SuperscriptBox["R", "2"]}]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"5", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"2", " ", "R"}]}]], " ", 
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]]}], 
        RowBox[{"84", " ", 
         SuperscriptBox["R", "2"]}]], ",", 
       RowBox[{
        FractionBox["75", 
         RowBox[{"56", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["121", 
         RowBox[{"84", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["25", 
          RowBox[{"56", " ", 
           SuperscriptBox["R", "2"]}]]}], "+", 
        FractionBox["109", 
         RowBox[{"84", " ", "R"}]]}], ",", 
       FractionBox[
        RowBox[{"5", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"2", " ", "R"}]}]], " ", 
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]]}], 
        RowBox[{"84", " ", 
         SuperscriptBox["R", "2"]}]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"5", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"2", " ", "R"}]}]], " ", 
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]]}], 
        RowBox[{"84", " ", 
         SuperscriptBox["R", "2"]}]], ",", 
       RowBox[{
        FractionBox["75", 
         RowBox[{"56", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["121", 
         RowBox[{"84", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["25", 
          RowBox[{"56", " ", 
           SuperscriptBox["R", "2"]}]]}], "+", 
        FractionBox["109", 
         RowBox[{"84", " ", "R"}]]}], ",", 
       FractionBox[
        RowBox[{"5", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"2", " ", "R"}]}]], " ", 
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]]}], 
        RowBox[{"84", " ", 
         SuperscriptBox["R", "2"]}]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"5", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"2", " ", "R"}]}]], " ", 
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]]}], 
        RowBox[{"84", " ", 
         SuperscriptBox["R", "2"]}]], ",", 
       RowBox[{
        FractionBox["75", 
         RowBox[{"56", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["121", 
         RowBox[{"84", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["25", 
          RowBox[{"56", " ", 
           SuperscriptBox["R", "2"]}]]}], "+", 
        FractionBox["109", 
         RowBox[{"84", " ", "R"}]]}], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]], " ", 
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]]}], 
         RowBox[{"84", " ", 
          SuperscriptBox["R", "2"]}]]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]], " ", 
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]]}], 
         RowBox[{"84", " ", 
          SuperscriptBox["R", "2"]}]]}], ",", 
       RowBox[{
        FractionBox["75", 
         RowBox[{"56", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["121", 
         RowBox[{"84", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["25", 
          RowBox[{"56", " ", 
           SuperscriptBox["R", "2"]}]]}], "+", 
        FractionBox["109", 
         RowBox[{"84", " ", "R"}]]}], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]], " ", 
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]]}], 
         RowBox[{"84", " ", 
          SuperscriptBox["R", "2"]}]]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]], " ", 
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]]}], 
         RowBox[{"84", " ", 
          SuperscriptBox["R", "2"]}]]}], ",", 
       RowBox[{
        FractionBox["75", 
         RowBox[{"56", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["121", 
         RowBox[{"84", " ", "R"}]]}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8026660724960403`*^9},
 CellLabel->"Out[42]=",ExpressionUUID->"0304661f-7af8-4f41-b828-7bd37ba7d9a5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"F\[Beta]", "/.", "solUHF"}], "//", "FullSimplify"}], "//", 
  "Expand"}]], "Input",
 CellChangeTimes->{{3.8026660809343977`*^9, 3.802666082925446*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"216c684a-3ac3-4c0d-a1f6-4efc7954c120"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["5", 
        RowBox[{"3", " ", "R"}]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["1", "R"]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["5", 
        RowBox[{"3", " ", "R"}]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["1", "R"]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "R"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["137", 
         RowBox[{"75", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "R"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["137", 
         RowBox[{"75", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "R"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["137", 
         RowBox[{"75", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "R"], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["137", 
         RowBox[{"75", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["5", 
        RowBox[{"3", " ", "R"}]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["1", "R"]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["5", 
        RowBox[{"3", " ", "R"}]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["R", "2"]], "+", 
        FractionBox["1", "R"]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["25", 
          RowBox[{"56", " ", 
           SuperscriptBox["R", "2"]}]]}], "+", 
        FractionBox["109", 
         RowBox[{"84", " ", "R"}]]}], ",", 
       FractionBox[
        RowBox[{"5", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"2", " ", "R"}]}]], " ", 
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]]}], 
        RowBox[{"84", " ", 
         SuperscriptBox["R", "2"]}]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"5", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"2", " ", "R"}]}]], " ", 
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]]}], 
        RowBox[{"84", " ", 
         SuperscriptBox["R", "2"]}]], ",", 
       RowBox[{
        FractionBox["75", 
         RowBox[{"56", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["121", 
         RowBox[{"84", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["25", 
          RowBox[{"56", " ", 
           SuperscriptBox["R", "2"]}]]}], "+", 
        FractionBox["109", 
         RowBox[{"84", " ", "R"}]]}], ",", 
       FractionBox[
        RowBox[{"5", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"2", " ", "R"}]}]], " ", 
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]]}], 
        RowBox[{"84", " ", 
         SuperscriptBox["R", "2"]}]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"5", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"2", " ", "R"}]}]], " ", 
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]]}], 
        RowBox[{"84", " ", 
         SuperscriptBox["R", "2"]}]], ",", 
       RowBox[{
        FractionBox["75", 
         RowBox[{"56", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["121", 
         RowBox[{"84", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["25", 
          RowBox[{"56", " ", 
           SuperscriptBox["R", "2"]}]]}], "+", 
        FractionBox["109", 
         RowBox[{"84", " ", "R"}]]}], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]], " ", 
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]]}], 
         RowBox[{"84", " ", 
          SuperscriptBox["R", "2"]}]]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]], " ", 
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]]}], 
         RowBox[{"84", " ", 
          SuperscriptBox["R", "2"]}]]}], ",", 
       RowBox[{
        FractionBox["75", 
         RowBox[{"56", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["121", 
         RowBox[{"84", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["25", 
          RowBox[{"56", " ", 
           SuperscriptBox["R", "2"]}]]}], "+", 
        FractionBox["109", 
         RowBox[{"84", " ", "R"}]]}], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]], " ", 
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]]}], 
         RowBox[{"84", " ", 
          SuperscriptBox["R", "2"]}]]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]], " ", 
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]]}], 
         RowBox[{"84", " ", 
          SuperscriptBox["R", "2"]}]]}], ",", 
       RowBox[{
        FractionBox["75", 
         RowBox[{"56", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["121", 
         RowBox[{"84", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["25", 
          RowBox[{"56", " ", 
           SuperscriptBox["R", "2"]}]]}], "+", 
        FractionBox["109", 
         RowBox[{"84", " ", "R"}]]}], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]], " ", 
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]]}], 
         RowBox[{"84", " ", 
          SuperscriptBox["R", "2"]}]]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]], " ", 
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]]}], 
         RowBox[{"84", " ", 
          SuperscriptBox["R", "2"]}]]}], ",", 
       RowBox[{
        FractionBox["75", 
         RowBox[{"56", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["121", 
         RowBox[{"84", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["25", 
          RowBox[{"56", " ", 
           SuperscriptBox["R", "2"]}]]}], "+", 
        FractionBox["109", 
         RowBox[{"84", " ", "R"}]]}], ",", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]], " ", 
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]]}], 
         RowBox[{"84", " ", 
          SuperscriptBox["R", "2"]}]]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"5", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"2", " ", "R"}]}]], " ", 
          SqrtBox[
           RowBox[{"75", "+", 
            RowBox[{"62", " ", "R"}]}]]}], 
         RowBox[{"84", " ", 
          SuperscriptBox["R", "2"]}]]}], ",", 
       RowBox[{
        FractionBox["75", 
         RowBox[{"56", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["121", 
         RowBox[{"84", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["25", 
          RowBox[{"56", " ", 
           SuperscriptBox["R", "2"]}]]}], "+", 
        FractionBox["109", 
         RowBox[{"84", " ", "R"}]]}], ",", 
       FractionBox[
        RowBox[{"5", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"2", " ", "R"}]}]], " ", 
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]]}], 
        RowBox[{"84", " ", 
         SuperscriptBox["R", "2"]}]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"5", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"2", " ", "R"}]}]], " ", 
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]]}], 
        RowBox[{"84", " ", 
         SuperscriptBox["R", "2"]}]], ",", 
       RowBox[{
        FractionBox["75", 
         RowBox[{"56", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["121", 
         RowBox[{"84", " ", "R"}]]}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["25", 
          RowBox[{"56", " ", 
           SuperscriptBox["R", "2"]}]]}], "+", 
        FractionBox["109", 
         RowBox[{"84", " ", "R"}]]}], ",", 
       FractionBox[
        RowBox[{"5", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"2", " ", "R"}]}]], " ", 
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]]}], 
        RowBox[{"84", " ", 
         SuperscriptBox["R", "2"]}]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"5", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"2", " ", "R"}]}]], " ", 
         SqrtBox[
          RowBox[{"75", "+", 
           RowBox[{"62", " ", "R"}]}]]}], 
        RowBox[{"84", " ", 
         SuperscriptBox["R", "2"]}]], ",", 
       RowBox[{
        FractionBox["75", 
         RowBox[{"56", " ", 
          SuperscriptBox["R", "2"]}]], "+", 
        FractionBox["121", 
         RowBox[{"84", " ", "R"}]]}]}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.802666083571973*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"45ba14ae-03dd-4070-8498-e92ca6359f4d"]
}, Open  ]],

Cell["\<\
The 16 stationnary UHF solutions yields 3  differents Fockian, only two of \
them are already diagonal.\
\>", "Text",
 CellChangeTimes->{{3.802666121554941*^9, 
  3.802666141418844*^9}},ExpressionUUID->"5132ca1c-5086-4049-9d9f-\
539d706507a7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        FractionBox["5", 
         RowBox[{"3", " ", "R"}]], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["R", "2"]], "+", 
         FractionBox["1", "R"]}]}], "}"}]}], "}"}], "//", "MatrixForm"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        FractionBox["1", "R"], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["R", "2"]], "+", 
         FractionBox["137", 
          RowBox[{"75", " ", "R"}]]}]}], "}"}]}], "}"}], "//", "MatrixForm"}],
    ",", 
   RowBox[{
    RowBox[{"DiagonalMatrix", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["25", 
              RowBox[{"56", " ", 
               SuperscriptBox["R", "2"]}]]}], "+", 
            FractionBox["109", 
             RowBox[{"84", " ", "R"}]]}], ",", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"2", " ", "R"}]}]], " ", 
             SqrtBox[
              RowBox[{"75", "+", 
               RowBox[{"62", " ", "R"}]}]]}], 
            RowBox[{"84", " ", 
             SuperscriptBox["R", "2"]}]]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"2", " ", "R"}]}]], " ", 
             SqrtBox[
              RowBox[{"75", "+", 
               RowBox[{"62", " ", "R"}]}]]}], 
            RowBox[{"84", " ", 
             SuperscriptBox["R", "2"]}]], ",", 
           RowBox[{
            FractionBox["75", 
             RowBox[{"56", " ", 
              SuperscriptBox["R", "2"]}]], "+", 
            FractionBox["121", 
             RowBox[{"84", " ", "R"}]]}]}], "}"}]}], "}"}], "//", 
       "Eigenvalues"}], "//", "Expand"}], "]"}], "//", "MatrixForm"}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.802666169534059*^9, 3.802666238618469*^9}, {
  3.802666274335866*^9, 3.80266629551689*^9}, {3.802666878072949*^9, 
  3.802666886057728*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"e6c9e6cd-90db-4d44-8da0-ad3de2b383ae"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        FractionBox["5", 
         RowBox[{"3", " ", "R"}]], "0"},
       {"0", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["R", "2"]], "+", 
         FractionBox["1", "R"]}]}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        FractionBox["1", "R"], "0"},
       {"0", 
        RowBox[{
         FractionBox["1", 
          SuperscriptBox["R", "2"]], "+", 
         FractionBox["137", 
          RowBox[{"75", " ", "R"}]]}]}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], ",", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{
         FractionBox["25", 
          RowBox[{"56", " ", 
           SuperscriptBox["R", "2"]}]], "+", 
         FractionBox["57", 
          RowBox[{"28", " ", "R"}]]}], "0"},
       {"0", 
        RowBox[{
         FractionBox["25", 
          RowBox[{"56", " ", 
           SuperscriptBox["R", "2"]}]], "+", 
         FractionBox["59", 
          RowBox[{"84", " ", "R"}]]}]}
      },
      GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], "}"}]], "Output",
 CellChangeTimes->{{3.802666172725923*^9, 3.8026661915348387`*^9}, 
   3.802666223995549*^9, 3.802666295797871*^9, 3.802666886356492*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"8d831873-d11c-439e-8414-7a5eeceb49b1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"x", ",", "x"}]], 
      RowBox[{"EHF", "[", 
       RowBox[{"R", ",", "1"}], "]"}]}], ",", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"y", ",", "y"}]], 
      RowBox[{"EHF", "[", 
       RowBox[{"R", ",", "1"}], "]"}]}]}], "}"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "0"}], ",", 
       RowBox[{"y", "\[Rule]", 
        FractionBox["\[Pi]", "2"]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}]}], ",", 
       RowBox[{"y", "\[Rule]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{"75", "+", 
             RowBox[{"62", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          FractionBox[
           RowBox[{"5", " ", 
            SqrtBox[
             RowBox[{
              RowBox[{"-", "3"}], "+", 
              RowBox[{"2", " ", "R"}]}]]}], 
           SqrtBox["R"]]}], "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"ArcTan", "[", 
         RowBox[{
          FractionBox[
           SqrtBox[
            RowBox[{"75", "+", 
             RowBox[{"62", " ", "R"}]}]], 
           SqrtBox["R"]], ",", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"5", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"-", "3"}], "+", 
               RowBox[{"2", " ", "R"}]}]]}], 
            SqrtBox["R"]]}]}], "]"}]}]}], "}"}]}], "}"}]}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.802666352843453*^9, 3.802666387320713*^9}},
 CellLabel->"In[50]:=",ExpressionUUID->"4945a4b2-10d0-4dd0-9b6e-5417c74af8d9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{"50", "+", 
       RowBox[{"8", " ", "R"}]}], 
      RowBox[{"25", " ", 
       SuperscriptBox["R", "2"]}]], ",", 
     RowBox[{"-", 
      FractionBox["2", 
       SuperscriptBox["R", "2"]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", 
       SuperscriptBox["R", "2"]]}], ",", 
     FractionBox[
      RowBox[{"50", "+", 
       RowBox[{"8", " ", "R"}]}], 
      RowBox[{"25", " ", 
       SuperscriptBox["R", "2"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["4", 
      RowBox[{"3", " ", "R"}]], ",", 
     FractionBox["4", 
      RowBox[{"3", " ", "R"}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.802666374630657*^9, 3.802666387627742*^9}},
 CellLabel->"Out[50]=",ExpressionUUID->"c57481c5-e784-4645-b3d3-1b54cd4cb2ba"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "R"], ",", 
     FractionBox["5", 
      RowBox[{"3", "R"}]], ",", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["R", "2"]], "+", 
      FractionBox["1", "R"]}], ",", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["R", "2"]], "+", 
      FractionBox["137", 
       RowBox[{"75", " ", "R"}]]}], ",", 
     RowBox[{
      FractionBox["25", 
       RowBox[{"56", " ", 
        SuperscriptBox["R", "2"]}]], "+", 
      FractionBox["59", 
       RowBox[{"84", " ", "R"}]]}], ",", 
     RowBox[{
      FractionBox["25", 
       RowBox[{"56", " ", 
        SuperscriptBox["R", "2"]}]], "+", 
      FractionBox["57", 
       RowBox[{"28", " ", "R"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<UHF_GS_min\>\"", ",", "\"\<UHF_GS_max\>\"", ",", 
      "\"\<UHF_ES_min\>\"", ",", "\"\<UHF_ES_max\>\"", ",", "\"\<sb_UHF1\>\"",
       ",", "\"\<sb_UHF2\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.802666816575615*^9, 3.8026669633827543`*^9}},
 CellLabel->"In[56]:=",ExpressionUUID->"5b1e83e0-e5a5-4a98-b6c9-1c4db1bebccf"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVlXk8FHgDxsc15EpMdyhCqeRMhVKqZe0WRSFKRG+iwyIRxRZFbzaVUnYl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          "]], 
         LineBox[CompressedData["
1:eJwVkXk0FPoDxcc69qwto01CqqflyRPqfpNKoY0ixBRalJQnlJQ8jC1JRUhF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          "]]}, 
        Annotation[#, "Charting`Private`Tag$25440#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVx3k8FHgfwPExjBlHjKuSkLGEypWrGJuiUImHRJE7sZG7mpXiUaRDSyZa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          "]], 
         LineBox[CompressedData["
1:eJwVynk81IkbwPExjK9zcpaoXKUtHbvZCtHzRCFROVMJG22ntJIjpa3cZCVW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          "]]}, 
        Annotation[#, "Charting`Private`Tag$25440#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV1nk4VV0XAPBzr1mmkClJZEiKpKjoHEWkCKkQUSFEIaRJkkpIUsaUqUwv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          "]], 
         LineBox[CompressedData["
1:eJwVk2k8FPgfgMc5jkkMWkfJEWWjU9b19/1FVJRdt4pd2ayjHCvXiqSGkDRi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          "]]}, 
        Annotation[#, "Charting`Private`Tag$25440#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVlXk8VP8XxqeyU19SQqGIIhGllDTTLkq2pIVsKbJWSspWUtFiKaEFKWuk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          "]], 
         LineBox[CompressedData["
1:eJwVlHk41AsfxWcG/TA1175NV0WkuL2VmyT1/YZKSMmSIkm0oq6yXPFK11pI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          "]]}, 
        Annotation[#, "Charting`Private`Tag$25440#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV13k0VV8bB3DJWMhUSQPKPERKk3Su0qgiKalEhZIxUShDRQqpJPPPkOJq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          "]], 
         LineBox[CompressedData["
1:eJwVlmk4FHobxscyxpayFaMNh4pOJ4pXJfc/pZCoLKkkOZVOpeS1lTayJ2fI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          "]]}, 
        Annotation[#, "Charting`Private`Tag$25440#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVlHk81OsXx2e+iCLbyLUUstOmkUiWiZTKlVBSCaFrT1HKDSnEpCxFlhJZ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          "]], 
         LineBox[CompressedData["
1:eJwVlHk81IkfxseY6UvkiJG70lJqaztW66rPJ52L2i2UEMpVcu0USVsb60xJ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          "]]}, 
        Annotation[#, 
         "Charting`Private`Tag$25440#6"]& ], {}}, {{}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{-3, 3}, {-5.346385447186369, 6.84788159833535}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"UHF_GS_min\"", "\"UHF_GS_max\"", "\"UHF_ES_min\"", "\"UHF_ES_max\"", 
       "\"sb_UHF1\"", "\"sb_UHF2\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.560181`", ",", "0.691569`", ",", "0.194885`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.922526`", ",", "0.385626`", ",", "0.209179`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.3523253333333333, 0.3137493333333333, 
                    0.46756733333333333`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.528488`", ",", "0.470624`", ",", "0.701351`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.528488, 0.470624, 0.701351]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.528488, 0.470624, 0.701351], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.5147193333333333, 0.28770266666666666`, 
                    0.06825800000000001], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.772079`", ",", "0.431554`", ",", "0.102387`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.772079, 0.431554, 0.102387]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.772079, 0.431554, 0.102387], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6}], "}"}], 
           ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.802666949082383*^9, 3.802666964404241*^9}},
 CellLabel->"Out[56]=",ExpressionUUID->"fe2e4aca-1faa-45c3-8155-20096138d09c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "R"], ",", 
     FractionBox["5", 
      RowBox[{"3", "R"}]], ",", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["R", "2"]], "+", 
      FractionBox["1", "R"]}], ",", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["R", "2"]], "+", 
      FractionBox["137", 
       RowBox[{"75", " ", "R"}]]}], ",", 
     RowBox[{
      FractionBox["25", 
       RowBox[{"56", " ", 
        SuperscriptBox["R", "2"]}]], "+", 
      FractionBox["59", 
       RowBox[{"84", " ", "R"}]]}], ",", 
     RowBox[{
      FractionBox["25", 
       RowBox[{"56", " ", 
        SuperscriptBox["R", "2"]}]], "+", 
      FractionBox["57", 
       RowBox[{"28", " ", "R"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1", ",", "3"}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<UHF_GS_min\>\"", ",", "\"\<UHF_GS_max\>\"", ",", 
      "\"\<UHF_ES_min\>\"", ",", "\"\<UHF_ES_max\>\"", ",", "\"\<sb_UHF1\>\"",
       ",", "\"\<sb_UHF2\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.802666982933741*^9, 3.802666983759595*^9}, {
  3.8026670648429413`*^9, 3.8026670651623783`*^9}},
 CellLabel->"In[59]:=",ExpressionUUID->"e096d0b5-6194-4b39-b564-43c2120b307f"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVjH8403kcwGebfWo5pz0olx85cdVdpSRK9f5YPat16ceextOOFVfupGjT
4qkmifB0JaKnx4/neKpV9CiN6JfKj3gUrpuv+bGatGwY+8EmI7vuj9fz+uf1
vDyj4jmHySQSKeQb/zumf4JOIulhEzgPW6062E4ZCzpP1sMMmsexWHSw1Ed9
lGarh9q04BCzSQeDsT3tdnQ9TOaLLcYRHRyafJ7r4qiHgYGcRVa5Dg7aZ/zg
t1QPpw6VdUY+0EHoRpfl0Xv0cIzl674zSgdbr29ivy3Rg9rTNexS6xhcc7LQ
PXYbAHbLk4V5o2DwaBGpDAZIZ7o1eGVqwbvVTZyUY4RXPlgzljsCHevV6Orm
cVgyP/SNumAYzq+rD1rcPw7HIkszbtcPQcUXh3G/7AlI77tTyFZroJKnZjkH
mYB7S3m83E0DdeyOLbF9JjA9EtY0HlVD8OzyRlaWGRjaNevsawehHa6P5v08
CWtuynYOLRyEtZ6XpJWtk3BRPZHlmf4ZHFpMM/sSv8Abrxj69lEVmKfjdUcW
TkGpi61lPFoFHFPEYdQ8BQ0Kj6aXik+QcVmWKBRaoOaCqYQS/gleV/H89jCm
oebck8YHQwNwuoQrrHoxDQqOcSI1YQA2uETxLkbOgOQpufJX+gDEhw00aRy+
glKgopwo/ghi/+E2x+dfwV4lPJUU8BHySyhnpRGzwKb5c/9Q9IPXuyvS7nlW
yF0uq5CJ++Hp5VU5xyus8OW3XVLfZf3gZC5LH/Eh4S5nc5rqoRIyURI1SkzC
grJXVRV2SkhRtsnnt5OwZW64d0HiB1hb8F6b5m2DjTHy9QGK99C5ZPWeA6dt
cLO9siGX/R6mRN/NSXhjg/nJr8ObmxTQc/eGzY4fyTjs8BOf2SAFbL5Zv5uX
QMYntwdfNbzog+w4b+27ejJ2+LfOGL2jDwoXMVvtXCiYuknku7KjF37JVs+k
xFCwJC6ueP7BXkj6zBLUvqTgwkBqWtFID7DJqzYsY1CxNCfz7/jUHkA63l6b
KComs6TCVPceSKnDZUW1VKw5HshMr+6G5H33wwRzbXG4oOxMXmg3BLTJWXMj
bbG7bFuTwigHhdPWtDk1tnhZUbWOmicHmvd652BEwxtTWkQ/bZbDiLNmaCOf
hoOz+j42fuoCbocHQ3ifhkfzy2M7c7rgXlhhpr2Vhp8EpC14uKUL6ur/wXFc
hO02PJZsMxDAnbgcgiQIPzwmWnRWQkB9O9M3/jbC1feUVf63CPC9a2bI7yDM
MMeJtDcIsOPzuyXlCJPr+2N5pQQ0Nq/4nVWJ8BnOrhWBRQSsKXyblP4MYacI
mLHkEODApN+kyBAuZENBsZiAZNe6C7GdCO/MHKTvP0OA1iyIkREIE6+6Sh1P
E9BS3rPyRjfCg98nMv9KIuCs093HzA8Ip/VOhYgTCBjTbOs4N4Sw8YRXZnQM
AeEN05VDwwjrvVfzlvxJQGvx/by92m8/P1fOQDQBEs4CnqcOYedH8VL+IQIi
ng2qXk4gfK53b9D+A9/6awXNS80IvxjNDlrIJyBQsKvsyiTCjj4nI+XhBDj6
PIo/aEH4WcZi91AeAamkI5yWaYTbRPIqp/0E6Hvd/H2/IixguAqIMAL41e8W
XJ9F+HODmpMfSsDb7HSL1Yqw2eDH43IJ+A8oQVxe
          "]]}, 
        Annotation[#, "Charting`Private`Tag$26570#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVi38803kcx2ebfbSj/JbKY8dl6af0+4d6f5KH0kW43O50LXTScDSluZNy
lR+VX/08pa6uul1UnOaUK0Jit/zIyaFffGfMj9m+Y5t8idMfr8fzj+fz5Rga
ExBGp9FoPlP7REGnjk2jkcDvCM/Jz6dgK0O9/gSdBHEK3zNBTIELVxnFMiaB
3ByCfW5S0BPZ3mDKJsE3wIqrv0zB9yNl5+ytSQg/N3pp5ykKgqenzlruQkLY
REaK/34Kvna3X7DPjwRWdmI0zKPAM2eDd90NEgZqVA4v7ozCJRuKzdmhheIo
iWCP+ANoOdI4hVYLMQ8HRdKaEXCWOSTGnx0Cg+x0pZAyQONaJTq/cRiu742d
X7nQACdWVa3/vHMYUrlFuWdEeij4YD68PEsHmhJTXlmFDoqClF626/UwZ8/f
aaUzdVDu3bg58o0eRDkdOb7Jw7BpYkG11ykDlFYfO16iHoIGyBm8sHAEkiTG
FXYRQ7DCMUNSJBsBb9vtW7VqLZhL9eM7RR/g1TWeZN8BLRjGYjQRM0cBYeZY
HE0LAfrdYah2FG7KNb5fZpCQmtksio2lYDPpyGI4kVBTHLTcz3IMUhenDyUk
ayDhRmBs8dMxiO44P3iyQg3r7EODzoSMQ/mawiYXCzXE8OTPe80/Asfq312V
uwYhcWV/vXXZR4hqsq6TFqng4g3GMcnuCfiJzcg0mqWCL5qyJW2fTcK2q+yG
4CMD8DjT9eyBgkn4Vd26wF/TDzaG/OQBLg0/KBPZCyL6IQ3FM0MTabj4kWGg
p6MPkjrqWy0aaNjfxIlzd28frLjyTnXS2Qh7t6UZL5H3wqu5bn57EoywX7rC
hwrvhdE4M5ODL4ywr+B3Jy6lhPa8W0bbnOhYmkfKvkpVwsbbVTuCDtKxWXgJ
NcxRQla0s6qpio5Lv9UdopX3QO5sD5mpPQO/fhDi4s/rgUVZyvEkAQOfKUr5
ppTqhvhuL+GjCgZe5Fow8/7lbvCmu66bb8nEgh+vFiKPbkCaIH+jUCa+PwOz
q9QKSCrH+VcfMXGUpD3E8xcFHN1ZyBNOM8aH+V3h3K0KWF3f6jUtxBhrXC12
mOm74K2N50mTh8Y4nmfnwBR3Act5re0mxMLvIo6snvrAgG1vnzufhUu2pFvM
teqCwEaOZWwhC5Pj0wvfNMjhHi83bfokC89uz7F6miGH8qqXODoQ4eA/NWwL
bzkE6jJ9kBhh65T0TU/Zcqhq8Fga8wfCqhlhlfemyWFpnsGy9Q7CpaK3IVdM
5GDK57eJ7yJ877ds5mGWHKprF+/1KkJ4vyby5RK6HJbl1sUnP0HYPb7jiHiU
AHMP9m1G81RveZpW0EvA0TnlKZGvEL4otDl1XUmAyiAUNLcgvGx7mtvZHgKk
d9uX3Gqb8nIz+SEFAcds8ko93iNc3UlVbOgkQN27pfHnPoTjiFhhSysB3z0b
K+rrR/ja9Wa99D8CZNcKL/irEHZbWHX5SQsB4gC7IEcNwlY/LMO3mwnY/aRH
UaFD2HZVNSuucaq/dKXWxYCwjBxJETQQsEbom589gvBjTgaXX0+ANbckJphC
OLbm+bMtLwg4TosIkI4hnLSaX+kuI4B87bBy6UeE+TM83rv9QwD/rya7nAmE
++sjZ82TElCXlUxNTiLsq2uJm1NLwP+ulVzo
          "]]}, 
        Annotation[#, "Charting`Private`Tag$26570#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVjms0lHkcgMeMmb+sJiZMo1pNjGRttcm2Yfv9Ta3QhWaztVMMs7RHnCxT
TNpBRbSdqEht2uqUtbmUULY9GzqzbkcutZRLb8ZlZFzK6zKDMbzbfnjO8+X5
8PClUaIwOo1G2/2R/x3eM2VKo5HQF8RXURQF3owP7mfoJHi7T6niZihwdBiM
ZDFJaLs+wpokKXgX0dlsZkpCqbyvaqKXgtDpiss8SxIcQuQF3GoKgtmpNi6O
JNjJjZ5r0yj4zoPndNifBJP+phqdJQXbr33t03ibhBuxeW5FrguQbaU3tfUb
Bxtcvo8Xa4Bx2/rj6vFxuCD7vlpk0IOgYaVCfmkCIguvBCoLZqFlyyDK3DoJ
bFS4tu7QDJz5Uum+qmcS7C/aFZfDNDyYMZ90yZiC4bBtXRJ7HZSIB72s3bXg
y/Nk2wu0UOnTsi3ijRZeXH3zq7fPFHguOFV7ndMB+oa78U7kJDTDtfdZn02D
PCy14ub9CdjEv1BW0jANi/j6cgY1Dub1WsO+uBkIjc+qCd4zDrq5qLEjy2Yh
oSrLWv6IBJE2MAzVzcKdx047IpeRkJreGhcTo4cWxnSyP2cMah+JXfw5cxB6
b7GHkPsBTt4OiHlUNQe+EW+Ay30Pbjyp+HyIAVjxaxzVrqMQtb+vRmM+D6Uz
Fsa1fiOgcB1usqyYh8QTcbn18cNw5TYjsSxwASy+Pf/kaeUQ2L28WNbxCQUr
jqlXZc9r4O/09Zd+ekBB1p7SiGyRBqx0BSkjDjTMZ5rNcMoGIQ3JjaUKGk4x
3HRXsAchSdXUbtFMwxXCNKvdP7+DTdffjiYLjLDX7JJTkoEBaLP/wl9y0gif
2fXM2ffAAMweX2wie26ENzp3Jd7oUkNn/l0j39V0fNUyUyo+oIatuUo/sYyO
Gy+fTOOo+yHjqGD0pZKOdVK7NcrYfshZLmww4zFw6O8SFwtmPzhnDBqSwhk4
Kc/G4sCtPpAPeEU/ecbAHmrEPefaBz709W5rOcb4Lssl4OHrXkBj4r1GUmNc
K/lX5qLohaRKXHDjiTF2OnyQ+dq2FxL2Fe+PXsTEBo23wvC8BzY3tXstCmHi
g/IXKaeP9QBhtT3Z5E8mHso+Eq7i9wBLsMXaE7HwdsH8OvNiFYxYa4Y8glg4
2m91x9mlKghoseXEFLPwWbm+UpraDUX7c9LYFAuXv09cnUzvhkrlC3w0AOGq
O5xdznFvIWAqfTfKQ7hb8ipfNkuAslm4IeoPhEnHosid0wRsyNdx2u8hfP+q
JMFOS4BZUFBHXiHCwmqb9DaSgOq6z3/wKkG4c4Ab6KYhYGNOozzlKcJdmzUF
lu0EmAtNcxmtCItlt7IYjwlIWFF5NqIN4ZDxzKUDpQSM6qLDW18h7BkerKp9
SEB9Yee6ux0ff1o9A88XEZBolf+XsBvhxuAIkptLwAfNjpZTQwgvL7lwGDIJ
OPTPXMnQMMKpzjmFgksENPxWnLV3FGF2dbKHWQYBeSKumD+GcEX/fc+uXwgI
fPpO/WwKYZ51bvuJ0x/77Ot1jjqEY1K6T0iTCPgqek/BxWmEBeXyH3cmEGDp
UB4VrEdYpEi3/zSegNO0I6L6OYRN1o9MIjkBZNdK1w3zCKd1hLMnjhMQ9Pgl
99oCwjUWczJCRkBjRoqeohBui82wr4sm4D8OAlEY
          "]]}, 
        Annotation[#, "Charting`Private`Tag$26570#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVkmsw1Xkch8+F/y+KsChyXbFSbSKVS75faqlmulDSKkeJWhTrNJXJpSLX
LSptWWoyw8ilGJQUSVIk10l73Nqatvodx+Gc43KO47r2xWeeN8+rZz7mgRHe
wRwWi7VrYf8z5PO4OoslhWdXevdz7zK4nTvinMCRAja/znfIYtDaip5kVKUQ
5bKiPySTwe9hve1L1KWQFFkhF6QyGKR4fsNAVwp9hTfetZxl8IhmsqG9tRRC
bEvn1LwYPOBiYHN8rxQKZ9ielGFwW9aWHa25Umg0EpV8O6eKt/Sm1E33yMDV
8E6O6kEVlJk2n/kqk8Fi+33aZce4aNliHBt1fRTSPMM7HFM42OFISabrGEiC
Kr4oH7IxYWODs9nnMai/FJBUP8rC0kmtMfuMcbgmirF4sYmF5X7UQ995AvQ3
f7snNpqHuh0dW8P6J+CQg2vhqGIW3OZsGj1S5SDm5YZmd85AO2QN31ytgJjf
TgR2dEzDBvOrleUtCjB6uMzZ9OsUaDVPzOw/Nwm7NH/JrB5Xgnw6QhK6XAk/
9d+y3mmhBO8J/2DSpIQSDJKZ7J6E5PT35/j8KRiMrMnLT1XAm0d+9nt1piGY
cUkeGJBDdK4P/9GLaYjuPm82sloOTgaBfn8cnYEU+9ADgowJiPD98lqoNQuN
xoOe7yTjEOsgatN9Pgsm3JzzlofG4c9c7oVK/zlY/oETFi0YA4uua5U9i+dB
V9ya17lnDGrS113/vXQekp9lGPgIRkFPXpw4ZMXC0FVPTtw9PgopJEolMJaF
qsVVwsmF7hc/tQm021mY0MWO006TwYbsj+LLlmw8srHqaayJDLpXrt8bEM3G
q5XCivynUlCe0Vh0+h0b1/xqpnE9QAq9RXnsnT9yMP7fs3ZythRc8xv2+J3m
YJxaSSzvsAQywi3FXQ0cvH+7qSCqbgRyVri3LDHgYs1WsV2vwQisyaAzF0O4
WCA4pbRLGoaobx6R1fVcXF8nAzexGHZw1jmt0lHBlLSYVMlRMRCJnxc7UAX1
iyoMLT8NwcU6LL5TrYL+xi4RgQeGIG5/mW+kmioe78ORnf0i2NQm8FA7qopL
NZj4v/xEMKC37fKiJws/VJ6qafg8CIylo74bYTDR3bl2mD8IQ/rCQRceg0Kn
lyZt80Lw6TDV4ZcxaJvX0zpwWwgPfHNSNOcZ9CpN/mjuIIS6hk4M9yFYZj7r
FtxGwWc8fRcpIDjN6xu4F0Ghod3dNuI+QZXq7be54RRsi+Q6gkKCN8L2pZ44
SWEJj9dTUELwcKq2rm0Ihcamtcc8ygnadE81vAqkYJfTGpVYS9C3fSBmwoeC
lrt6Pvc9wQ+Zu3XjXSjEGdUlhXUTtKriPhQ7URDLI0PefyBYQxXRvo4Umkt6
f87rIZh4lV+7diOFC3pFT93/IXhFO/HNwDoKI0LPjkuDBDnpbye2WVA4/Gq6
fFBEcGXvqeEKcwotd8tueokJBrwtMDQ3o1DgvczPXEJwa8ADvTkjCv6137/W
jxP0D/505Zn+gn8ru8laTjCthW1ro0dhc+Tu4msKglAYtCj7Bwq6VlURR6YI
doleHjyvRSGeFerdPE1wc/D9TpEmBWmfsYPtLEHXhLzYQxoUeI+7lmXNEeT/
XRLQuphCa0bi1Pw8Qc2xx2e3qFP4Dxq3TOM=
          "]]}, 
        Annotation[#, "Charting`Private`Tag$26570#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVjHs403scgGdj35pLEpUujyKOwsmmK47PN3V20im3kuw0IY5bLNKTci9E
t63r45Cebo+o1c4euj2koiK5/kY2ua4xQmaYbC6n88f7vP+8z7s6iOMdQiaR
SHt+8r/Du8dpJJIC1Ivk1MxAJeykfHc6Q1aAg1//x3S2Eqyt5EeoOgr4pSjU
OsNPCX2Rkno9mgKEqxgl57yUEDz56oqpsQJswg8MF25TQoDB2WUO1goo9bJb
TjdXwn5n03V/eyog4nIqPUI2CjtyfnOrva2AwzBW5hE1CjdM1DQzj1E4cudU
U2OSAkbNqo/LRkeBkfMhqDBkBCxrVibFX1aCjlW7TurUMDRslaOrLmOQkgwv
m7hDcGZThdOq7jHQJiRcpd8gPPlhOObAHQfdc428pjXfQMiSMxc7TcCR087C
vfoDUO7WsD3yywSkz/UefL28H7bNrnvHzFbBgL3aKNFaDvWQM3zNZhKyOqUr
Nvj0wYbVF4uFNZPw/Ppdi4SrvWBYPTG978QP6KRf9JLXy0Cl4YxELJ2C3a4L
opdZyMB7gh2CqqagMzPfLzTuK5y9JDoRG6uGmym/x2aLpPChhOXgaaQBi1eC
aAZTCgm3fWJLXmuAYpbNu/G0BxxNg1jnA6dhcwltr9mmHuD4St/3G87AyIpd
gVnF3ZC08Vud8asZCEirDDvg2A3Xb1NSitmzwO/i37W91QUWTbxise4clFzY
37LnbSeUXlp/+eiTOdALr1PunukAE9XDjEErEqYxwk4aMDsgC8VrByWRcFSF
uy8vqx1Su+paF9aT8JV/Pt7s6foCG3I7htIttfB5Q952Fv0LNK+hex5K0MIu
wtlFbRfbYOq4/rxjn7TwIdu2PrlGApKie1q7zMmYqxF47w+WgMv9Cg/WMTLO
XB/2rLJdDNxoy6GmCjLO5ZvJFrHFkLfctUbPlIKt1K3+SNwKtlz5dGo4BRtP
1vVVBrRCfC8z5sUbCo74+oOdKPsMbuT1jmuNtLGR+dI7PXGfAY2wvLSCtLEp
I+tpqO5nSC3HD2++0MYLJ/w6bPJbIHmfwDdmvg6mPR44oOXYApvrWpnzA3Vw
ytvStgCiGdpNdqTPe66DA7Ze6fE62gxUy62LtyEq9tqZFjm5pBkGF/cPOPtT
cVju49iQUhH4NJgZxQqo2K4s4a/2UBHwffOyDOao2MqNd+v8UhGUVzTiaB+E
a7MHk13eE+AzfmkPKkB46GPedvVJAirqXe05DxDWp5AiBfEE2BepjFoLEZZ+
z38dfIIAPX9/ccEjhMVRQYqGOALeVdkdZgoRdji1gFPIIYCRVxufUYZw4BZ9
SWAIAYautPsUEcK7KgWrVJ4EJK8oz4xsRvhge2PHvx4EDKliwkUtCNfw9aoi
3QmofiT59Z4Y4V66cKX0TwJSTIpeunYifCvteVsjk4Dv/X80pA0gTIoyuPDM
mYCDlRrhwDeE3XXLqXFOBNTkC655DSH8KXiaT3ckoMB7CWv1CMKHcsmJjzcT
wC7rk70ZR5j9wdXiAeNnfyO3ylr18y87PhVCJ2BLjPtD3iTCC/KU6jX2BBhb
PeMEqBEeDi9IuWdHwGlShHe1BmH+vlryYVsCFG0rN9rPIOySaCo0tyHA/2nT
kpxZhMM8Ms5J1xJQy81Qz80hbAuIe9eagP8AgONOSg==
          "]]}, 
        Annotation[#, "Charting`Private`Tag$26570#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVjX001Xccx697Xd/CDMdjZfRwPZSNogcP+XzcSrMdwkjnnhKSRXm4JCQP
G0ptoaiUWlqNPHTNZLR0SW0kDxmFas2a/Fwufpfrcu/1MPvjfV7ndc7rnPfq
4Cifw0wGg+GxtP8ZNiBVZzBoqHd/URzxhoWfs8ad0pk0cG080hp7WWhpTh1T
Y9Ngvld6T6+HhUNH+zs01WmouDLGfNzGwpCZRxeN9Wj4/uXbVCshCwO1zqyw
s6SBHddp5XCLhXudjdeHetGQUcNJ8DzCwp0F293bimgo9evzslYw8bK+Qt10
jwTa9Nl5WiuZKDFtiRuUSMChXrvSbL8KclpNkhMuTILR4388eZUM7HSgSJ7L
FFQ4Gv7iymRg+pYmJ7OBKSjquTdzpH8BBLPaU3Y5Ugjo7Xt9tWIeqniUm4HT
NBjz7BL51+ZA6N654+ibaXiY2GBZV64E14X1T93OyuBVjXvf9QcK6ICCsfwN
M6CzqdR14IMc7Fefr65qnYF/c44XpKyRg3bL9Jxv/Cy0/azJlvNmQaaMmgg3
ksNFomGXWT4DPtMHDpNmOUjKszOXz8rgTHZ3fEyMAn4w5q9r9pbBH/d5dl66
Sgg6Z3V4UDgNSUV+MfcblKC3agjbLabB0TiY913QHNj3bmwV35JClP/734e1
56G28mKWjpEUkjePtOs9mgctAev0qStTcKmIlVp9YAFMnBODOJwpWNuVW92n
sQiDeufzBwST8DDb5kK0YBFEYuf7sbsmQV9WljlqzsBW4d64k+8lkEUSVIOT
GWiQH1ZSnSSBtL/be3U6GFgXVhz7ylQC9tf+EmdwVDDW4hv5kUYaetZt9DqY
pILbq6TRJaE0yOM+Whb7XAW31sxGOBvQ0F96W+WLNUxkilMKejImwOVO0x5e
LBO/vnFw+77xcciJ5Ii7mpgoqHUQrQ0ch8KV3FZNYxY2cH7rjH8+BtY51Fxa
GAvlE2zyZNcYJHxw49c1sjDmiu9b5QMxuDNtHK10VXFDjHOutrMYyATPWyVY
FUMmc0/VPB2FNCGWXa9TxQTaIvrq7lFI8a305y9no+GaC4t1r0Zga3uv2/Ig
NqZGbHOLDByBt/o7M5bVsjHBhutkTYtAjeNg4ErUsFhOCxrPiWDUYFjkHKCG
B7vzFJvNRODXaaobU6mGGlxbs66GYajwL8zSWlTDj29Ov9MJGQZh0wuM9CN4
dbRQkMgaBj9ptgcpJhiZzj87V05BUwfXNqqEYNnx8PSkMgpsS2W6vXcJ/kkb
CRR3KdAMCOgrLie4o45/Sf4TBU+bPz3kVkXwmLtOufwmBZsK2xIy6wnm2aiN
MPMp0Oaq32F1Ewx+ZB3vcIqClFXC00d7CGo8sz4hPEmBWMYP635JUGrdeGdH
IgUt5f2f3e4juMUzOdfzBAWp+qUPuO+W/kv8b4VGUzA+vLvzGxHB+IxnRTdD
KNj/RFklGiE4+cnLfItDFLTeqMz3Fi+571BtZRAFxT6GvNUTBF34snONARQc
qB8abJQSfC3tPTS4b6m/fK3ZUkZw3dCKzgh/CrbxPctyZwiOhpqEzfhRoGf+
a1SggqCpo4uVxlcUfMsI92lREsxa++WeS94U0K9NNtvOEwxvld429aIgoKbL
sGCB4I+pmyzKPCloy8lULC4SdLys7LP3oOA/dUFRJg==
          "]]}, 
        Annotation[#, "Charting`Private`Tag$26570#6"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {1., 0.2837301632653062}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {1., 0.2837301632653062}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{1, 3}, {0.2837301632653062, 2.8266665104761985`}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"UHF_GS_min\"", "\"UHF_GS_max\"", "\"UHF_ES_min\"", "\"UHF_ES_max\"", 
       "\"sb_UHF1\"", "\"sb_UHF2\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.560181`", ",", "0.691569`", ",", "0.194885`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.922526`", ",", "0.385626`", ",", "0.209179`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.3523253333333333, 0.3137493333333333, 
                    0.46756733333333333`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.528488`", ",", "0.470624`", ",", "0.701351`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.528488, 0.470624, 0.701351]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.528488, 0.470624, 0.701351], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.5147193333333333, 0.28770266666666666`, 
                    0.06825800000000001], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.772079`", ",", "0.431554`", ",", "0.102387`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.772079, 0.431554, 0.102387]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.772079, 0.431554, 0.102387], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6}], "}"}], 
           ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.8026669841867123`*^9, 3.8026670655896463`*^9},
 CellLabel->"Out[59]=",ExpressionUUID->"0194e55a-69d4-4f78-9043-1ffc49c4ff4b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "R"], ",", 
     FractionBox["5", 
      RowBox[{"3", "R"}]], ",", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["R", "2"]], "+", 
      FractionBox["1", "R"]}], ",", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["R", "2"]], "+", 
      FractionBox["137", 
       RowBox[{"75", " ", "R"}]]}], ",", 
     RowBox[{
      FractionBox["25", 
       RowBox[{"56", " ", 
        SuperscriptBox["R", "2"]}]], "+", 
      FractionBox["59", 
       RowBox[{"84", " ", "R"}]]}], ",", 
     RowBox[{
      FractionBox["25", 
       RowBox[{"56", " ", 
        SuperscriptBox["R", "2"]}]], "+", 
      FractionBox["57", 
       RowBox[{"28", " ", "R"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "0", ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<UHF_GS_min\>\"", ",", "\"\<UHF_GS_max\>\"", ",", 
      "\"\<UHF_ES_min\>\"", ",", "\"\<UHF_ES_max\>\"", ",", "\"\<sb_UHF1\>\"",
       ",", "\"\<sb_UHF2\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{3.802666992018578*^9},
 CellLabel->"In[58]:=",ExpressionUUID->"6e2f0f8e-60db-4310-8763-4994effde913"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV1Pk/FPgDx/ExxgzFl0alTSmtkJX7K7TaTtV2+RaNbAdyVY6VTSVpFoOy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          "]]}, 
        Annotation[#, "Charting`Private`Tag$26302#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwBIQTe+yFib1JlAgAAAEEAAAACAAAAsVfI9///B8A9YN13HMfhv4p9DZMd
/gfAYl8H6IHI4b9io1IuO/wHwPgBW5DnyeG/Eu/cZHb4B8BQLLSJs8zhv3SG
8dHs8AfAdNuhIE7S4b84tRqs2eEHwFiRFuuN3eG/vxJtYLPDB8BM56JQOPTh
v83NEclmhwfAplhaXjsi4r/Qb8S3qAQHwPjmXA87ieK/DOipp5SKBsBx8ZgT
nu3iv2WoKaLlEgbACkCK5D5U47+mlBK6EZEFwMUaen+ayOO/H1cu0+cXBcBQ
MVdfPjrkv4BFswmZlATAJIYzrky75L/+e9JKrxMEwP1T16xqQOW/tYgkjW+b
A8CNhfpAwMLlv1PB3+wKGQPAxD3WVlNX5r8q0M1NUJ8CwADkNgBd6ea/HidW
ufonAsAto28H9H/nv/mpR0KApgHAxuX5Ylcs6L8NA2zMry0BwGiVYVRZ1ui/
CIj5c7qqAMAZkz1agZnpvyFVISYqKgDALqGTuRtl6r/k8Peyh2T/vzFKJja7
Luu/VI9/VHFg/r+mqlVJeBfsvzbabPiubf2/5WgwrjP/7L/mfCzXomb8v/Rv
Mt3EC+6/0a8gy2Bk+79A3sVWDCfvvy2PesFyc/q/qYLItWYh8L9YxqbyOm75
v0GO7hsXx/C/9Kk4Jld6+L8EongBQm7xv8sd/249i/e/n9RHhkYf8r9x6Zfy
2Yf2v86R6hDp7/K/iGGWeMqV9b/KZPmiRsTzv20xZzlxj/S/THvLfX/A9L+N
kWwP4o3zv3SrwD7V0fW/H57X56ad8r9T5SaQaOv2v38CFfshmfG/x8QHTLQ+
+L9QE7gQ8aXwvyUwhZvdoPm/umgfdxRv77+mO7O3myX7v3Fac0Kzae2/BT39
9yAD/b8LpZIS+obrvwvqYJPk//6/QZ9WWK176b/eJtivPL4AwFry5aIIk+e/
Oamkw0gZAsAo1LlgjIvnv0ReSMMJHwLA9rWNHhCE579oJKtsziQCwJN5NZoX
dee/lsW0ymIwAsDMAIWRJlfnvwRxBBe4RwLAPg8kgEQb578uVAUZGHcCwCIs
Yl2Ao+a/1hOmAMjYAsDpZd4X+LPlv5HWrkfKqAPAdtqIh9mr5b8LA/reJ7AD
wAJPM/e6o+W/zKtB/Yq3A8AcOIjWfZPlv2UvvOdhxgPATgoylQNz5b+yRicl
U+QDwLSuhRIPMuW/sIve50ghBMB/9ywNJrDkv+UiJdGwnwTAFYl7AlSs479n
lmTpELAFwAYrORLApOO/ouK+um64BcD2zPYhLJ3jvyqZFgPTwAXA1hByQQSO
47/WZc4Wr9EFwJaYaIC0b+O/TcNgH7bzBcAYqFX+FDPjv6dFg4QGOQbAHMcv
+tW54r+ErcOv6cgGwIRnGorZf+K/hYIXBzoTB8AZnjBO
          "]]}, 
        Annotation[#, "Charting`Private`Tag$26302#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV13c8lV8YAPDXKCNKJA1KkaQ0kGh4pUiSKNGgKISUmZkRsiJCaRkhKf2Q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          "]]}, 
        Annotation[#, "Charting`Private`Tag$26302#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV13k8VO8XB3BKaRGi0iJboiQlpbQYKVlKVLZKQkRFEqmI5GsvpdCOUmTJ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          "]]}, 
        Annotation[#, "Charting`Private`Tag$26302#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV13k8Fd8bB3BZUlKIEtEiqW9RyTcpaaSkVEjCrxBFSIXIWrITFaJdKnyL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          "]]}, 
        Annotation[#, "Charting`Private`Tag$26302#5"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.772079, 0.431554, 0.102387], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV1nk0VP//B/CZi2yDbGNNtBMtkjUN6qNVoclSKluiZC2Jj+UnW8q+pHxs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          "]]}, 
        Annotation[#, "Charting`Private`Tag$26302#6"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{-3, 0}, {-2.8843880228089938`, 1.4192888684976785`}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"UHF_GS_min\"", "\"UHF_GS_max\"", "\"UHF_ES_min\"", "\"UHF_ES_max\"", 
       "\"sb_UHF1\"", "\"sb_UHF2\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.560181`", ",", "0.691569`", ",", "0.194885`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.922526`", ",", "0.385626`", ",", "0.209179`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.3523253333333333, 0.3137493333333333, 
                    0.46756733333333333`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.528488`", ",", "0.470624`", ",", "0.701351`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.528488, 0.470624, 0.701351]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.528488, 0.470624, 0.701351], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.5147193333333333, 0.28770266666666666`, 
                    0.06825800000000001], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.772079`", ",", "0.431554`", ",", "0.102387`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.772079, 0.431554, 0.102387]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.772079, 0.431554, 0.102387], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6}], "}"}], 
           ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.802666992487718*^9},
 CellLabel->"Out[58]=",ExpressionUUID->"93354289-5870-4a58-8645-15687481f6f5"]
}, Open  ]],

Cell["\<\
For R>0 the sb-UHF solution is a minimum because the symmetry breaking \
minimize the repulsion and for R<0 this is a maximum because the symmetry \
breaking minimize the attraction.
For R>0 the sb-UHF 1 is the \[OpenCurlyDoubleQuote]bonding\
\[CloseCurlyDoubleQuote] solution and the sb-UHF 2 is the antibonding \
solution. There is a point a which the bonding solution becomes better than \
the ground state of the symmetric solution, and an other point at which the \
anti bonding solution becomes higher than the symetric solution.
We can do the same reasoning for R<0.\
\>", "Text",
 CellChangeTimes->{{3.802667157011733*^9, 3.802667224512665*^9}, {
  3.802667317088167*^9, 
  3.802667703017641*^9}},ExpressionUUID->"789a8640-f72d-4922-b335-\
731b29963b66"]
}, Open  ]],

Cell[CellGroupData[{

Cell["sb-RHF and sb-UHF", "Section",
 CellChangeTimes->{{3.802667725814394*^9, 
  3.802667746919107*^9}},ExpressionUUID->"bde0567b-610f-4ced-b3c2-\
7e3d365cb7c7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Table", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"EHF", "[", 
        RowBox[{"R", ",", "1"}], "]"}], "/.", 
       RowBox[{
       "sol", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", 
        RowBox[{"Length", "[", "sol", "]"}]}], "}"}]}], "]"}], "//", 
    "FullSimplify"}], "//", "Expand"}], "//", "DeleteDuplicates"}]], "Input",
 CellChangeTimes->{{3.802667799808613*^9, 3.802667806414116*^9}, {
  3.8026679066720457`*^9, 3.8026679098476467`*^9}, {3.802667974398497*^9, 
  3.80266799336724*^9}, {3.802668297661792*^9, 3.8026683149503307`*^9}, {
  3.8026683572393217`*^9, 3.8026683618062153`*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"7a8160f0-d63e-44ba-bf07-5585a342b529"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "R"], ",", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox["R", "2"]], "+", 
    FractionBox["1", "R"]}], ",", 
   RowBox[{
    FractionBox["2", 
     SuperscriptBox["R", "2"]], "+", 
    FractionBox["29", 
     RowBox[{"25", " ", "R"}]]}], ",", 
   RowBox[{
    FractionBox["75", 
     RowBox[{"88", " ", 
      SuperscriptBox["R", "3"]}]], "+", 
    FractionBox["25", 
     RowBox[{"22", " ", 
      SuperscriptBox["R", "2"]}]], "+", 
    FractionBox["91", 
     RowBox[{"66", " ", "R"}]]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["75", 
      RowBox[{"112", " ", 
       SuperscriptBox["R", "3"]}]]}], "+", 
    FractionBox["25", 
     RowBox[{"28", " ", 
      SuperscriptBox["R", "2"]}]], "+", 
    FractionBox["59", 
     RowBox[{"84", " ", "R"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.802667807868717*^9, {3.8026678912227173`*^9, 3.802667910302764*^9}, {
   3.802667975588361*^9, 3.8026679940600986`*^9}, {3.8026683027001553`*^9, 
   3.802668315712294*^9}, 3.802668362411025*^9},
 CellLabel->"Out[76]=",ExpressionUUID->"e68ed154-12f0-46b6-9989-c127efd9455e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "R"], ",", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["R", "2"]], "+", 
      FractionBox["1", "R"]}], ",", 
     RowBox[{
      FractionBox["2", 
       SuperscriptBox["R", "2"]], "+", 
      FractionBox["29", 
       RowBox[{"25", " ", "R"}]]}], ",", 
     RowBox[{
      FractionBox["75", 
       RowBox[{"88", " ", 
        SuperscriptBox["R", "3"]}]], "+", 
      FractionBox["25", 
       RowBox[{"22", " ", 
        SuperscriptBox["R", "2"]}]], "+", 
      FractionBox["91", 
       RowBox[{"66", " ", "R"}]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["75", 
        RowBox[{"112", " ", 
         SuperscriptBox["R", "3"]}]]}], "+", 
      FractionBox["25", 
       RowBox[{"28", " ", 
        SuperscriptBox["R", "2"]}]], "+", 
      FractionBox["59", 
       RowBox[{"84", " ", "R"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", "1.5", ",", "3"}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(s\), \(2\)]\)_RHF\>\"", ",", 
      "\"\<(\!\(\*SubscriptBox[\(sp\), \(z\)]\)_UHF) ???\>\"", ",", 
      "\"\<\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(z\)], \(2\)]\)_RHF\>\"",
       ",", "\"\<sb_RHF/h_RHF\>\"", ",", "\"\<sb_UHF/h_UHF\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.802667919328829*^9, 3.802667935065711*^9}, {
  3.80266800579642*^9, 3.802668008099038*^9}, {3.802668173388748*^9, 
  3.802668258274457*^9}, {3.802668365597969*^9, 3.8026684259096727`*^9}, {
  3.802668527443355*^9, 3.802668573044139*^9}, {3.802668800392159*^9, 
  3.802668806115922*^9}},
 CellLabel->"In[92]:=",ExpressionUUID->"19e9fcc3-462d-4146-8b67-65de6066d591"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVj3s01HkchseMma92V6usTUWRpQ4pmZo6lT5fWUJWpBnU0GRms4diKaSI
SEVuXWhF2tbkWDXlstFxibPKrSOX9RszJgxmJmc1upqGmWFn/3jPe97z/vM8
1mHRB38mk0ikn/T5vw9UbDcikdQQHoF8mUw5xKd9PDFhoIbVvUf5FQFyKGUL
+p9T1JB2X+ei9ZfDjIlNcSZSQ1Vw906+rxyyE5duMv1WDZaEMujLPjl0essD
7NaowWy2ZGXlTjm4Kq/f9dmthrzAYnC1kgPdeYZRdEYN+xL6Xzi/lYFT/i7P
QI0asi+qTGrPy+DzClZQZNwcFESU+56wkEFxoDBklXIOqtXv0wtaJuFwpNJ9
Jmoe+r/Pmi4MnYTxiv6N5lPzEEeJfhWCJiG1wUd1PFIDZ3oUd1weTgD5ouMT
v7caaBl4XGTEmoD9CZLYfJ4WdgjSznGMJkCwx8p0VqEF26dzOdT6cRBudq55
zNHBVM6j/aUnx2FC9KcHVaSDpuniz8r144BYT5tTghfgiidtvmlUCp+0N+h+
AwvQv+XqsZISKagTaNnuzEXY4InZmwKlMFY5KiaIRfjO22vRyUwKHZS9pqN2
JBxVPzq1UDMGDhbSyslwEu57+SSCvW0MTnXJXG/ySbje7cO53LZR6JBu9Q5U
kLCBaU+0aP8oGA9u73ljZ4BX11hG9IhHgMG+d8CGa4DXpPBlvNgROOHLcovh
G2CRZ8EsjzoCGUQMI2LcADuGmHZG/fEa8nZgvpMlGZsrrP557/YayqmH05eE
kvESZ+9BW6kE7oUPH8u5TcZXudHkxAwJVNDLq21ekzFzhX1dm60Efpf8kHTZ
goJD6541+nQPQ5L5Vx6FQRTc7TwksU4YBl7Lzgv1RRSsO66adVo7DE6a/sZ0
IQVPfBNQuK5XDMrlFjGWyw1xwAuH2+fTxFB/s/pW10FDvHcqMd5/ixh4DwTN
VnmG2EhlK+W8EcGajbOHsvoMcaZLa4JlkQgaXcumS42p2H6t1rDVXwRedENd
qhcVnwsp8mQZi0CWW5USl0XFue9eMnqfDwE3pc3ArIOKHRnX2/hpQzAjtp5t
N6JhG8e+rdm7hyDChM718KJh7oa2Bp85IXRLKvt+zaDhC4K8zreNQmAsi3os
aKdhk3hV3auzQrgkuZVTQEGYU3ZwwA+E0HHhtMIbEF4WGa3cSBOC2fWSquWp
CNffahqK7yLAY7vD2YwmhC1aSZr5awSYr3bm3WhG+GNWQzNVv/9d2OF77xnC
6V27Ck3yCchr91jX3Iow2Sjzil0uASJmWPfn5/o/VhcTkEVA5OmiVbwehGnK
dmZ1GgH51ahx7yjCgy3PfJJPERBWsPS+3xjCpfYDf2fFErA10SwvVIrwI7q/
728xBIixDffsBMKSjkv3a6MJWNe35+saBcKy8tRD05EE/DUTd8T6HcILLEZN
KI+ASwNJ7pvfI/zjvqrkk1wCgurSN7t8QDjz4S+hSWEE6JKvUYI/IWx+J/Po
bY7e11jwIP8LwuFlLpwhtt73Q21BqRph+gs2oThCwPRgQ8rDOYSVqrKjqsN6
/pLOgE4Nwoucu7VmwXr+1F4XoRbheapvsm2Qnp8nXC/TIWx/cyV7WyABNM+R
ZR8XEF7ptnjAnaX3cZBpFhcRfuWtDWIyCfgPGx1SMQ==
          "]]}, 
        Annotation[#, "Charting`Private`Tag$39213#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVkXs01Hkchuf+tUorcsZBjpBaFBvhWPX5TrumSNLNvRtjO6WTLFIoUy7V
bDJNLl1ou6gzTQldVsmlc5SJ3dZlmyn8MBhDLqNJ6qcxZmf/eM/733ue57xL
YhK2xtEoFMomQ/7vzWJvIwqFhGgBZ7+NVANHTn06OEAloYi/OmL5Kw1ciy5v
f0knoSNi/gPPRg2oTR2unkUkJD5U5wQ3aODcsQUrzb8ngcaJHsut1sDrwKFt
TrYkkPqKJGOxBjgToj+C/Egwqjd5FHVWAx6r1F6Xj5KQJneS2W3SgLvwpw1h
WhIq7Bdzs1s/wmd2aHh8ygyEb/uaytrzEa6GyXdaTczA4Ub3RaLJSYiMn/BX
H/oGjmXltVTLSegXt7tajnwD36WVQ7bhauDXBH35NV4LfwliWDcvTAAte8WT
kHEtlFA6Cp69G4eNqd2/CXmzEBku9279cRzK19qZT6tmoaUryk+UMwZyt1UP
K/boQHlboMsbG4WB93e5zPc6kG1IuHouchRQ6NO6zIg5kNxNCT3T+AGmZi96
hHTMwZy42dfb7wOQqaxz/jv0YB3e6RdYMQJ9kt5OmUwPzhJXdNh5BKT0dea9
ThTclbfSb8WjYXCxUUgG91Hw+Hy5d6nXMCQ1KzkFZRTsTLb/XdKkAqnCMzBM
RcGJ4t2ld7aowOSt95thJyqufPGBZzw4BF7RNzY7xFIxs3Aq7lDmEBwMDv05
sYyKxVb+yY7sIciRJXod6Kfio8eiZy2eKSHfB5e5L6Zh+Nomk+1Wwh1mZNZ3
u2h4tNiJ50JTwo19XXvzrtBw11Ln2qLyQRB73KlyIGhYGQXC7u2DcL3bMeO0
DR377sv6pZAyCBmWxtyicDqeq/cRxj0eAF6D78nqy3RMdakiN/IGwF3b/jxL
Tsdl2c36ZusBmDCzSVxsxsDD0dMtdfJ+qC6oKm7eysBCO/Z5fV4/8O6V19nl
M/B8kTmDHdQPtq7T2wVtDGzL5WgqWf3wnHNr7JoJE2+ZOeVbK1VAgAdDxw9g
YonV+sH7vytAeb4yM0XAxA05cw9CghQQm9lItZAyca9ONNlipgB155LpJiMW
dtR2rwu83wcHTD1iuQEsfEAoKsjw6YOWbknb4RwWpuSK9q5v7QWvhYcqyptY
uMY2JX35nl7I7S7OK6QjrCpKYLG1PSA9mawKBITTzX32H7zSAxaikkozPsJg
L2Ys8+wBrrdLWk4twrHyDvGidwRYWq/iXaxDeK0bxy5NRsDonE/wjXqEA3en
N/b9S0B+E9e+7gXCpUY+effaCHi/I6bl80uErZctWuHfQkB88mUr3huESzbv
v8SvI0BYhZ6v60V417ydanYZATGFC26H9CHcrFvZceomAZ7HLPJ3KRB+yp9W
TFwnoBM7xKYNIGwr8c98WUqAfdvaeQ9VCF+a8qlPKibgsTolaskkwtvRLegS
EJDbkeHv9hHh43ZlrevPEhD+Z5bbGg3Cj13dBU9OE6A7foEeMYVw9NA/Jy5k
E8A1Kb8n/Iqw0cWEuI0nDL6aR4XXSIQbvpgG1GQQMPa2JvP+DMKjOqOwH9IN
/CWvt73WIvxqeECDjhr4+a1r5LMIBzdVn0g9YuDnyZcpdQjroXn1cDIBrA09
Cz/NGfblpuywJIOPi1Kr1xv+MD5jL00k4D8fP1Gs
          "]]}, 
        Annotation[#, "Charting`Private`Tag$39213#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVz3k81Hkcx/E58FUyq3TYDpVJ7S7FUijl82Eziw4etTFNx0ORNuPRxqZT
TLk2JUdUIscjCTWkbPeo3SyjcxJyreg3xjEZ14zGjGHtH+/H+9/na/He37bs
Y9BotE2T+/+9Cx0NaTQ1+Hg6cY5c0cCRM0Mhn+lqWN84YOOWroHsncL3lUw1
pFqtqGalakBhws48S9TQXHpAV3ROA+ePs1aYfqOGOn+v6O5IDYi9OrcuNVdD
lh1bHLtPA659qTkb16qhUp5XD/YasLdTOGQcU0POQJTTTcko2CY7e/hp1eAq
EfD5zFFQzvHl8sNHwVyoibi/SQ2Zfg275vaNwmVlWcnq/K/A4/e5Kw5qYGrp
S9sg1Qh0FL63NuvWQIH5vDRL3ggIHm8cCeJrIcHo2TnFIxUwYpb/6fNFC53K
utnOS1Sw4WhLWHLgGNCOLPRXZCtB6LLIVCUbA2zuu9c6UwkNNnZ3S/11EH+Y
U3M7Yxg+NxZx9Bt1sEJ1ljtgOQzE96Eoavs4jAjiM4uEQzA8dtHep3YcbDPC
z5i7DYH6qMF5920T8Hr16kxe7SB8Km5rqq+fgEgPZabjgUGoZrqZti2lIdMm
yIQYDYLV/PZiaj8NPz4vtmoqHIDfa6Suafk0rNn0qb3CZwCq21d6+clo2DrY
9qixpx+M6xzfdC2lI+vV0x/j1vaDw848b3YAHZuX+RQ9zVVAyGbfn0Lz6Zi0
pjdkQNcHsfWhDsEddFyoJ/0YwO+DJCfMt13AQGmgasvF9i9QoM+LnrKbgaKQ
NOvvvL9A3v7mPYlXGRicOOYy87UcCu0LytitDHR6WB4mcZNDbsuSiPj5TORe
KrMsed4LEWZTOZe4TJSsH+5au6EXAp+tOf0gg4mG00rYo+96wFb7/kl0AxPH
DOV1af490DdjfuiCGXpYmWAkuT3SDQ/Syi7XbNFDQRk/2CO+GwJvCUWLkvQw
zm4ON9aiG8ytVb8kSPSQlxk5/crDLnjiel2ebayP4v7Z725yu8DTXk8n8NTH
8nFB53qdDKQX7kSFJ+ijXIeFjGsyCIh6QZ9VrY8f/kjx/stdBoqmxaoqQwPM
sTQPlvV0QrCJfQDH0wDNDkmd/VI74WVLseRQrAFWLvc17nHrBIfpB0uFVQYo
3sVMZ/dLIa7lcmI6k2BoybclrOtSqD59WOYFBKODWOIAnhRmpWbdmSEguDsu
zCTbWAocR6sTsU8JtnZ0bG2qpsBsnl3gRRHBHxrCXt2ooqB33GlzXgVB1mDR
vrB/KEiq4liInhNMWaekT3tBQeO2vS+VlQQLunY2YQUF/MMZcwPfEEyg5Y7f
KacguYw8cWsj+De1aqw4j4K96awbPp8Iupx8LTqZS8HK47OSdrcTvBbDzduY
Q0ETsgNOfCaosXB+q8iiwELiYnRXRtDs59SKlVcoKFeE71jcT5B3o0ZZdYGC
uNoId5sBghcY1h8yEing3o+2WTdIUG61/EPIeQp0p1KY24cJ1vqPOJomUMAx
Ft5K/krwKp2Vtid2snfwXnq2mmBEkCRyVQwF8rrHUbdHCb4tNTg3JXrSnyXe
KtYSVCY/IncFk37Bu3UNYwTNI6yOxUVN+gMblkl1BH8d0k7ZEUmBgce/04fG
CUKupcjm1GSPlVQ7MUHwe/vrKXoRFPwH5qteOA==
          "]]}, 
        Annotation[#, "Charting`Private`Tag$39213#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVz3k81Hkcx/ExY+YrIscqRfMIu2xJLEWr+HzokRBRNle2FVMtOlSOkqLQ
lszSgUhKqXWXDrZE7SO5qo2SRK5+P0M04zZjxrH2j/fj/e/zpet/cNtuJoPB
cJnb/++aa6nAYEjA+QdzR8UmKYSfHtn3RU4C1ziqafkNUsjyLWqsYknArp9b
uPmNFESq+lfPEQkUH3m7IrlaConHVFZpLJDAz/ygI3qPpVDr1ONuwJWAwi6v
yeAsKdgKL153Xi+BbWvE2hcCpWBuJrJIPyqBSm6XyUKmFEyT1zl4yiTAHWIt
O2w0CWOLPLyCwyah8zNj/oYDErjq2fzrEuEktGskromrFINPsHCj6IAUFuZE
e4/NE0N3buNKrT4plHQrbrIMmoCYJ84Te4JlkJlYqSF+OQ7MOONHbt9k4P8w
fb+C8Thsjmg7nMybgssOZu5Ot8egyGaZxrhgCn6XJapxF49Bs4nZ/bt+01CX
l+sclDkKX1ry7Nkt02AdVrw42XAUiMffFdHeMzAxZDo/pHgERqcumbu9m4FK
5cf799iNgCSCk7hx+yxMH7zduOvdMHTmd3z68GEWTqa+14TAYahh2Wl0GDDw
x4kyRKVhMNLpyqf2MtDEl68akTcER+po28s5DPxNld3StXUIarpWO3kKGBhy
ttj6tHAQlJss3/QayOHNkGvZr20HwcI321U/QA7D717hPfhLBPu2eGw4lCOH
K/mK3r0cEcR/OGQR1C2H0oxX+3aECyFpLeaYLmXiFF8pMlP4De6wfWLn7WRi
YGlq/dmd3yB7b+sufgYTw920fMraByDX/E6J/mcmWl8xm5rwGIAbbd9H/aHD
wtZW8XLvj/0QpaVon+rFwjhVtYOOvH7gPbM6VZbOQp2bmwQ3Br6CqayxPLaZ
heWFjNHik19BqK5zaKm6PDqcjHZategrlF0uSavbJo8Zqwwtduf3Aa+gqGJZ
kjyaaxe+VnHoA+7K8V8SGuRRltZXUNnVC+W2twaylNn47LwowSq2FxzN5adj
HNloIVQxMVvRC/Sf96LDEtjo0/8gKvy1AAKiX8hp1rDRuGPE8FyEAESfdMer
FTi4/uMLFyOuAIJUzQPsHTlY6ac9warrgfq2/IaQeA7+y/f56dXxHrBQO3C3
qJqD19olR/1W9MCZtjR+Covgy1CuXWgXDTWnQgVOQPA7mXtcezoNmhcz76nH
EORm3tLZ4kqDvaVRZPxTgr1TVZuSlGjQ0jbjXaogGFWaco+nSEP/zNot2ZUE
k31hndU8GpKq7fUqnhMcGuSU9nBoaNnuXz9WRXCrfD3aMGkIDk1fwntDsHWP
1Z1xCQXJJaTcroNg4I2P504IKPBPUbnt1klQp0Cs59lDwepjmkk7uwh6zti0
m9IUfEL9gMgvBOUzjB/R3RToNdgo3RcQvJ43POzSTsFDUdgO3UGCHN2tGQZN
FJx5F7XRZIhgjp/nBuZ7CrxKY02shwlmdRordzRSMH3iAst7lKAr04KV+pYC
e+WigmQxQc1+7aPkFQVaww9SsiQERUbKhnQdBQNNT6ILJwlevHJr4nntnD+z
1r1WRrDnRL44snrOH/PWunmKoAuoLvd6OefnNRvS0wRHnrKPr6migOPQrjYy
Q3BBVrxQ/cVcjxEtm52d6zmfEDP0DwX/AeGfUBg=
          "]]}, 
        Annotation[#, "Charting`Private`Tag$39213#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVz3s01HkYBvAxg68UiURyyeVoNzbCIuR9pw5hW6xbKqlcskunEro4ROWS
Vgwht7WVtlWaUGJPiG6kPSI/xmVcZphR1qKIpmbGrP3jOc95/vs8hiHHfcLp
NBrtx+X8314Vdko0mgjCI4mnv78QTl2YOzomJwJOS1Bxha8QyoLYb18wRJCR
LtaU/CSEGTXjkgwiguBzqiXlnkLIPKu6RWO1CO4JA4c+7RLCKw+hr6m+CFjV
k9uuOwiBOZ37+24nEbSsuOSrs1EI1lYztkVnRKB/JyajZEoAlixHtz1iEeCJ
tHL3BAF80goIjIr7AkdTC4rCtARQsodzQGf6C6h3bQ3ZVT8O+6KmXWaOfYXM
77k/a/qMA7/irbn2+6/g3OBYeHJxDJIf7148EiWGWJhT0ysYA3rKd4+8/xWD
6lMtepzDGPxwmnuSFSaB6KIjTonv+MB23qixMCGBBCsb760sPnAsrB5UHZJC
XVX9nwZMPoz133FV6JdCRn1iUucCD0jAX01Je5fgVKKWc/xtHsxLrlp7dy/v
zRKt34J5IDqtmOniL4Nyma2xVJ0Ho3dHBnp7ZeBX6RUxkz8KbYwdGiOmNHwY
sjjxi8YomOny7o5H0DDXP2NoNGMEYtoFzLxbNDTpzbMxURmBNp6Nx54JGio6
fE3vzBgGlR67jnemcmgpOx5ZvGoYbINueBmHymEC7dQdeskQHPUM2Bl9Sw4d
7CfsHI2HILU32jaSL4cys6eP4uq4kG2Ptyz16Lhy2EWr0JMLtxX2XVwRTMfW
OuX897xBuBExePhKMR3NBXn7dyYOQoX17RrjITquv+nuo792EK5zTRLSdRkY
sN0si101AAnayq4FgQxsrD2yMtxvAMKaHc7XFzEwS6l5cnq+HyzFbxsuchjI
CnKyNy/th2l13Wg9dXk892Zfir1bP9Tn1Vxr95HH14XbDhyc7YOwSnbTxmx5
5I6or0sp6wN98wW/y13y2Og3uZnh3gcNzPKpMhUFxPjzbAMxB9yt5aXJ7go4
/vKM16VqDgiyqpPiLisgx+3kpcuHORCa9FxOs00BdX2y07LXc2BmwHChVUkR
77U/Mwzv6IVINetQV3dFPJaVkxaZ0guvuXe7TqQqIn9qQ6OA2Qu2a45VsVsV
cZWtRmaEuAfSuNeu5DMI6hkoyNY19EDb+dgJDyDoVOh4LjyxBzRzS6vVkwne
X+InzTr2gKudWXxqI0GJZmbMVloPaG+wCrvaRHB8V3fOtzIK/lmy97zxhGCu
l1674RIF2a2uRk0tBAMKai+oSyjo9w95/ekFwXidXw0XPlMQFVukE9ZB0CBn
Trl5lgJWDWnYMUKwIqY0LnyUgpB81T+8RwmODmndPzRCgc1ZzexgHkFLzhbZ
/mEKBtA4NH6MYHGs0ZQPlwKjLueVDyYIehx8Ocnso6B2Jm6/4SxB/5vGSSad
FKR1J7hYfCC46WY3GL6hILDuosX2jwSNgie19TsokCbmMPbOE3T8hrlW+28K
XFXYlazPBE3mwEKljQLtjw/zy0QEHzd2P1BupWCq53HSvS8E0zMfeiq9XPaX
vvJ9JSboF+nTyXi+7E/u3M6REJxWU66Ve7bsD+NsEkgJfpim18haKFB0G14z
t0Rw8c22Vmnz8h8zgVgmI2h6oXJe/ISC/wCn7Uwh
          "]]}, 
        Annotation[#, "Charting`Private`Tag$39213#5"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {1.5, 0.308531749686184}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {1.5, 0.308531749686184}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{1.5, 3}, {0.308531749686184, 1.6767676219336236`}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"\\!\\(\\*SuperscriptBox[\\(s\\), \\(2\\)]\\)_RHF\"", 
       "\"(\\!\\(\\*SubscriptBox[\\(sp\\), \\(z\\)]\\)_UHF) ???\"", 
       "\"\\!\\(\\*SuperscriptBox[SubscriptBox[\\(p\\), \\(z\\)], \
\\(2\\)]\\)_RHF\"", "\"sb_RHF/h_RHF\"", "\"sb_UHF/h_UHF\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.560181`", ",", "0.691569`", ",", "0.194885`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.922526`", ",", "0.385626`", ",", "0.209179`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.3523253333333333, 0.3137493333333333, 
                    0.46756733333333333`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.528488`", ",", "0.470624`", ",", "0.701351`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.528488, 0.470624, 0.701351]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.528488, 0.470624, 0.701351], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.802667935498431*^9, 3.802668008801146*^9, 3.8026681942917852`*^9, {
   3.802668243660515*^9, 3.8026682587919397`*^9}, {3.80266839812646*^9, 
   3.802668426727483*^9}, {3.802668528556148*^9, 3.802668573429961*^9}, 
   3.802668806860057*^9},
 CellLabel->"Out[92]=",ExpressionUUID->"54f8084a-0a1a-41e6-ad4a-e23c2b5d4588"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "R"], ",", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["R", "2"]], "+", 
      FractionBox["1", "R"]}], ",", 
     RowBox[{
      FractionBox["2", 
       SuperscriptBox["R", "2"]], "+", 
      FractionBox["29", 
       RowBox[{"25", " ", "R"}]]}], ",", 
     RowBox[{
      FractionBox["75", 
       RowBox[{"88", " ", 
        SuperscriptBox["R", "3"]}]], "+", 
      FractionBox["25", 
       RowBox[{"22", " ", 
        SuperscriptBox["R", "2"]}]], "+", 
      FractionBox["91", 
       RowBox[{"66", " ", "R"}]]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["75", 
        RowBox[{"112", " ", 
         SuperscriptBox["R", "3"]}]]}], "+", 
      FractionBox["25", 
       RowBox[{"28", " ", 
        SuperscriptBox["R", "2"]}]], "+", 
      FractionBox["59", 
       RowBox[{"84", " ", "R"}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"-", "3"}]}], "}"}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\!\(\*SuperscriptBox[\(s\), \(2\)]\)_RHF\>\"", ",", 
      "\"\<(\!\(\*SubscriptBox[\(sp\), \(z\)]\)_UHF) ???\>\"", ",", 
      "\"\<\!\(\*SuperscriptBox[SubscriptBox[\(p\), \(z\)], \(2\)]\)_RHF\>\"",
       ",", "\"\<sb_RHF/h_RHF\>\"", ",", "\"\<sb_UHF/h_UHF\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.802668459143282*^9, 3.802668518171247*^9}, {
  3.802668777937096*^9, 3.802668790951467*^9}},
 CellLabel->"In[91]:=",ExpressionUUID->"0f9b8d2a-dca6-4a62-bd03-16a3aed40353"],

Cell[BoxData[
 TemplateBox[{
   GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVyms0lHkAx/EZzIxu2tRBVEudsCG7HBUKi3DI9aAwqxCFtjBCM7JbaCmt
bo5sK7Q2Kl1QSbZ+fyUtKZRxJ9cJMc/DGHKdbV98z/fNRyvwmEewHIPBcP7a
/69LT56VyThkatzY18tLCO6iYuDzRQ5ptFpux/MWYvRIWk38Aoe4ODS7Xtwr
xArHy1dnZjlkrafHs7c+Qrgo5G2TSDnksu9RhoO/EA1x/0SJPnNIlaWPnvUh
IYQBkpG6Fg6R5dqbOJ8Qots4oCPrPoc4brfSQbYQJtLT/Ih9HKKolPWYJxaC
Q2u8WsHhkGXuKqVT5s0YU4+stCljk/vZK3JWnm2GWtDy+McH2GSo2bBxZ28z
ng9s6KNWsonlkEE506QFtxJj2SFPWMQ+cVNK6qUWFHikdUYHssiokUXm7vEW
aPqp+Tsqs4iPyNmVu6cV3b+OZHMrFIgkhba2KGmFao9xqkmYAnmVv9M2bE0b
Dh4z1S5QVyCqT7OMbsW2YUoj+ZRXlTzZekFV8FHUBnk5h5RanjyxNW56t8Gj
HV4sd+f4dfKkwqnrMLe2HU93qFRVV8uRzsJVwpu2Hbj2t4eoJUaOrFP6+VrJ
0w4QQ2H1Zk05cnI7c6OnZScCJO88zOqZhHF9IrcInbBrUso+F8skRh2T0Quu
XbAcXJp1XItJdteIOhz7u1BqmGCl3cgg/JcNtayobhzJ3H5zNZ9B3Ph78oaV
PyJ3x+Gy17oMUqu3I9ji/kfUr749qVsiwy6NSHUnnR4M0SunzVkyiJN+yNp7
qgfTVgfdOoMWUeGXFj/f2oMLb2y1px4u4KZ7+RaDnb1we5y9/8clCzh0YbZU
7UYv2GsGqbWh89D+i2fzC6sPdkVP5sMr5nD1hTiOG9OH+DL+Aae1c3iTF328
caAP7Rsf6XD5s8j1l5418+5H5b+CcNHbGRi2+tXFtPQjp/d79qL+DATlCRn2
3gNgm0StT0/4gld3HA5ofBpA0Fzeubsd0zDRuPK6/vgghrQcf1own0acrSTc
ZYkIU6cT7lT/PoVib4FFUokIc955buvHpBgWaS3t8vmE1GC3qLFdUhgnSfsi
1Ydg0RQ7Lb44Caf2Xs+5/iGMPDr/4eS4BLf3ZViZFg3j2/eG+mdsJLCO0SWr
rozAKYB0aORNIOyPkP01gs+47lYj7mNOIMfDdHfd0VEI+P4Jm7zGUel35bzB
2TG4qPYdHC+lYeTFc7cuECMqkJ+jVUxjruzShiNFYmTeVW53v0cj9KX9rcxi
MXpsbFxLCmkk287MSiq++oh8U142jeJQh8LKBjEyakKUpGdoPIljSYpnxegU
fC774kNDq6KiaNSVAuN14oTuXhqjLKMxVy8Km5XXGfh40ljIz1Z85EvhaOGe
G+UuNOgUvaakYAqyprtpfBsazAeb28wEFDZujQiY16cRYzwYzSygYHdC8U/9
LTT0DczbThdRCK/Kbebq0IhUN9Rll1B46Nvo9EyLRtfoRKrys6/+N6NtCSo0
emM1T1h/oBD2vjbi3moafmaZLh9aKaSvD7rT/Q2NMt4LlZBuCq2llzUtl9GQ
KbomXhymML+o53dMkUZ++vPvtlAUNB2rMnJYNHr6F6urJinYZnAb6uVoPBhW
4wbMUgjtmVzKYNDYZakyIpNR+A94sLMB
          "]]}, 
        Annotation[#, "Charting`Private`Tag$38952#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwV13k4VVsUAPBzzfWEKJUkU5KEBvIkJEmmBg0qSchrUEmiJFPSpMgjQ4Oh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          "]]}, Annotation[#, "Charting`Private`Tag$38952#2"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.560181, 0.691569, 0.194885], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVjXs0lHkch19jzAghRUVptCUV6Wi1LtWvVqZdoklZqVFmBiVCUjRmnQlp
RZtdbEmStUkXXcad6vtjZiiSS5JLCacwb7c3jPtl9cdzPuc553POY8IPdvOl
EQThMsv3fX7x7PjMDBM/qqgci9GSA3danf9kmom3CDZXs2b9U2DiM9EUE4O7
gP9YUw5znZIvj40zcVhAhMqwhhxc6VkbB5VMrG9o2+0zRw4NEY9Cez8y8THv
FENbhhxe8QbJ56+ZeGRNnU75jAw6N/A60u4z8bYLV16YDMjAWhktDNnHxDcM
c7oKG2XApIzkc5lMbOHlpUi+L4PPhscrHIoZWFqwg2dzXgaLBFqiIm8Gvmd1
5jzhJYMn7417vuowsGS1lpn2Ohncigln+JWo4XHapa5/lFK46Zb4Joyvhm/3
qNZplEiBdWDRQSc9NbxiysCqPEIKnWIyg1tOx2JPySZjCyks7NoQb32Ujs16
kl6celcJPsG2pjcN6fiuqGm/RWIlDBudPeMuU8UG3oddlq+uBFXaL3/UnFDF
++gzTb3SCnBX2+0iWqKKA1ltmmXOFVBmYyCrqqJhn7RbDIcaDOk33Hpfn6Lh
n4M87LzYGLDlq6qVLBretIwwN9oLwBt84WZXr4IfxAVV2ek/AXazdkZCuAqO
2L7F6lT6I0AfNNJOmqjgUYVjWS+9HPIto7aaNhK4n6pH4FcKgZd+ypkvJLDW
0FYdLVExXLc5UlxtRuAfHZm+c84VQv3820NmkhlQ/6S7rCE4H/opnRF7tRk4
Eh+bzVA+gJGtPpw3gmnAspiOhLa7kFS73XS4YArEaeGP217lAKco49C2OVOQ
lNPiWeRxHRgLPnxd7D8JYoH+2MSRZGDfLZkMKJ8AItTOOqU1EETFQm/nxbMO
BgvO2cWj9uWFq7jCcfD+NZQc17iGKp5GBvTWjUHDZaKSFXQLZXavZ0ybj4F4
l7agY54EMaxDl16MGoVc/3mEpagECSayEvI6RkDXzLcsxRhQv4mT15T9CASm
u47VmErRcHTUnao/h2FTXl+RirAaTfyWxVn6WQneXtJo5mgtivflhH7erAS7
T8eNU/Ib0Jbm8JEvfw2BX3PweUfJS0QWXnj5+7dByE3l8d1etqBlTZbmcQ6D
8PfhY/rF2e3ImYc7jLIGoKc9xpGe24mucZ596VEZgMA+2SF+QjeKFB6M+sH9
G3RxRw2CHN8j14U9Pt/yKRjN8jC2X9uHQvnCTJOHFMi+Ht6gbtuHLuXpte++
RwG3lc1+y+5DXQ4OuyS5FCRxfEWZ/Nl/yH+2JzIoyL1K1cZe6UOpz/y0lXEU
xC3Zv7BVsx+9ifxYPOpJAV3UdrR2qB8R1TEDZh4UPFAOl2arKtBKvSUWnnsp
6AkTP43VU6Cg3J3/lrpSkEKc3sxbr0AzzXmJQgcKhobv2McGKtDydSG8SXMK
LtfFb4voVSD2afWr5msosLm2J+WdUoECZNdbuKsoCEvM1+Gokahgf6PzYxMK
Ct5y0neuIBH7nNXGKAMKVvgZyAv4JDraVBNybz4FTS2RRn6hJLq4VHCnU3e2
X+3SyIomUWt+MgtpUqBbuihckkWiyem1B4LVKYji6J2Mf0gilpMsNVONAkb2
6S/+FSTansptqKdRIFYcJPc0ksi/a0iDIChY/7Q1eEc3if4HAfyMVg==
          "]]}, 
        Annotation[#, "Charting`Private`Tag$38952#3"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.922526, 0.385626, 0.209179], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVyns41XcAx/Hjcs5RUmIppGGFSrP0qGiFkZooiZqcLNeKygklh84mS8xt
KpXVcWlbSEpUlObzbZNoXeSy4xbHiUNH6vvL/T774/O8n8/zvAx8gl39FVks
lvPM/u/zlDNj09Nc8teo/47ovWLwplR8yqe4JLYowOgnTzHeH06sjprkklyn
ggVneWKoOZ6/PDrGJZIDuhuTvMTYrpy9tn+QSyJsZLd/9RGj5uSjEFkvl1zN
SDV5GChGg3e//Ll4xhdsiVaNFKNtjXdL+m0uMSyNyB+5IobF4GkB/zsuUemb
k/SwUwwu1X2ixuWSxKt1kYdWNKJP59hjuxIOMWwp1eHzG7HId07U/f0cUjTf
8ql/eSPKO5dIP87jkHrW/Ct6s5qQFxPOCShlkx1WTjZuvCbkuCa2hvmwSeZm
SW9AYRP0PRd5OWqwSeqT+zfVFJrR9qNcxCtTJuWG7rvUPZuxULIm3iJQmZTZ
mJeI7jTDL9jSKEdHmWilR3gOqLRgSPdMtHuFEsn7hpOYE9gCJcWtcc9Clcgi
AWl4UNUCd/ZO56jFSoS3ybFSzbwVD9drVVRWKhLdn93a54paceUPV5n4hCI5
0hZvaa/8BsSsoXKZviJJqEo+t/LkG3j3v3S1eqVAhPJARZeeN3ConytKCFcg
2t2yDH5AG6y7ZqcfN1AgJmHL6+y721BsJrQxes0iyV0Nwk1+7Th8ad11TQGL
mLDjonlMO7LWHyx5asIiVStVVAM2SvBK88aASdE05LWrC3+LkaCHzhvewJ4G
f1SnYGedBMM2fi6tvlNIs85LX2fQgV/+sTcaujuJix1eNc0RHXC5L/redtYk
nI0N38U1dIDzWddH7UMT2KplqyMyk8LhZulEUNk4MlY3cqsvShFVIti/TXsc
WqzbGZUTUjQb3jPmCcbQ8OhB+fWAt3hcFRkkezGKu1O2Q22St8js+IozZToK
V3lD4YW9neBYhOilCEdw0ngz+dDdCd/x7ISClmHYbK3NkB7vQo+B477JDcOI
7XSIylKVYei0ML8yeQhhcaGXY8pkGN+d7aLXN4gbQ6v2LTnajXh/l5C+jYOw
YS050GTbg0314cMfUgcwZqY8rWX8DvJ7SXWnmH6knevcYKUpx+e1Zqaxdv24
kGdc32rWi23epEU3+xN2pR1U+NbjPTJcqj9IFT7BwqRXuDSrD5ECL+EX7gys
qCh8jvlHbF8o9WOKKfYENMY6BlOE+AgyDe5QrK9eruYYSnGpQKN55y0KL+1A
tlM4hcTObkdR7sy/vMVtzw8znv+7ZaiIYrlHd05CCkVadcDcwViKQMv3848U
UrRG9paMeFBwcruqDAcoWE9jPpnsofCtzW8PG6FYprF4lYcbhf+1E3eqJyiO
5jpde7CdIjFdlhLJZjBdX5AosKOwM9p3irWQgeGXfO8JU4qvpUrOqVYMHCJU
rpquoBh6kWetbs0gqCLrX54xxbXcvxecs2Nwd+/rbX8aULw8/PpEhtOMP2u+
VqhFMVsetLvZi0Fg7TP+LU0K9ZHiW3xfBil6vvlt6hQ1SaXTsw4yaCw+r2+t
SqExXHdx8zEGE1MrPYNVKJbc2C/tPs5A37EiLZNNQfLTVicJGNin8WpeKVIk
x1uctfiBwSHJwGwWi2JpJ1smiWHwH7zeq3U=
          "]]}, 
        Annotation[#, "Charting`Private`Tag$38952#4"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.528488, 0.470624, 0.701351], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJwVkHs01GkchyfMjHJrqyMluYXZmrDb1nbZerWkEiWXrpNyqS2UScruNCQO
rU3oYqVy60aJbRrmYibfV2lCdk2ohDScmBlDfsO4D1Z/fM5znnOevz7WQRE+
R3VIJJLXzL6xLi1xfHqaiv3G+2a/dBYDY0o/qGKKinc5a5ZvmvHe8JQa9iQV
X2p7MC1wEoORx/WbY+NU3FxR8rLYUQw79fLXDA5RMTJ7w71OF4P0d3Fkt4qK
aS8ElrtpYngXONhT94GKYy1XXrxqKYb2VYGtWf9Q8WjCDw62RmJYPRTPYu6j
4iZhvwFHJgIqYf7KiErFtbBo6xaOCPoWn6505VMwM0Y/7hVbBGbBhmzeEQr2
y3BuSv5FBBVflnb2m1CwYLvWwmmsHB4lRFOOCchYbBxyOLSgHAp8Utqigsi4
2ZxBZnuVg9VBswCPeWTs4du0fi0hhPa4nmyGSA/rD3z21VwQwkLZquTVoXqY
tB19fG0ghJCIdfYFi/WwYUXMLc9UAQybJ170r9LFd+ZsHdcd5YOuzrY/a8/o
4hQTuZX/IT74k3d7sZfo4ieTluST93lQvta0SiLRwRXhveX1rWVw+4FP94dz
OvhG2p4zhsZlgJ3eSeysdHCcQwr/slkpBA7+57O+fhZeVsjNCV/CBfcm4+zL
0TPefftxcT8HUNecrLPWs7DewYJSzqOnwHWKdbF/S8KkD5GeD3klEJ7588P5
LBLGnq7p/JtFkLf2OP81jTTzT/QXWkgh1M9/rKE9m4bRj92mEer7oCBMRjaQ
pyG9wKahuiEPRlxCvNuCp0BWsPHF5hVZkP7GzX64dBKspn9iJhmkgjcv+/Dm
2ZMQx48NsX4XAZQFXf2LTmgB+yqO5d6OQe5PBNow0QTgYoV+ztwMxOazjuxY
NAFWa3yFvFv5qMWmzIHBGgfpMp4w3+0Rqqw+H9b97xi4PX+wnOfCQbkdzpQp
+hhoHNvtJIY8RFkdaZEWOwq9+/ZeK2oRoeCJ/MvFrSNwN4Ntf20II4W1x6HJ
DSNg72xg8tS9Cg3HxxZJUodBFmArPeldjSb25Htb9A1BU5fkc2JqHUo+6h3Z
t3EITtFqFHYyKdrUFD3y9aoG/Pq/N82TNKKesiuNMepBaPgU75zW/B5ZNjjR
k1wHQetty2+514J2BOJW8/wBoEf5sKo57SjHu+Zr56wBGPu0izw7pwOdZwXE
2vqr4VRER29y1Be0c2FniJpLQJLaz6syUY4ig1i51hwCyLz4TvYNOcosntey
u4SAPV5C21/vyZHM1XXXs0ICRnTTa5R4pmfeX3cmmwB+tfBCiVaOMmqOGQ8l
EdDuvvLvBecUqO28ij+6n4Cw0N/mXmEqEel1wgBtLwGb05RdV+KUyG7ekpX7
/Qi4lLXsdFa6Ep0q9Lwr3EnAkWx6nfSpEk03FaewXAk4EO+eWqlWIhtHZqCW
TsCrJAdH7tke5P6H/h36cgJyGt9nBif1oLCqvPcMBwKuRRLbLDN7UOmBtzue
WxNgM/xdgUAw01/6cU2sKQG1AV8ZUdoeFNpQyyyZT8AzaapBnJEKpVkEF7XP
JeAvQ7VX5lIVauZet0IGBNAr2ksVLiqknVpxMEKfAPkLTa+NjwpZeVRl5JIJ
aJR0fD4erEJuGQxpvQ4BC+UJmeVRKnRCpplDIhGwcctLC7MkFfoftDOcJw==

          "]]}, Annotation[#, "Charting`Private`Tag$38952#5"]& ]}}, {}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {-0.9583333333333334, 0}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {-3., 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, 
       "DefaultGraphicsInteraction" -> {
        "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
         "Effects" -> {
          "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
           "Droplines" -> {
            "freeformCursorMode" -> True, 
             "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
       "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> None,
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{-3, -1}, {-1.0946969018243715`, 0.8601189214042858}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}], 
   FormBox[
    FormBox[
     TemplateBox[{
      "\"\\!\\(\\*SuperscriptBox[\\(s\\), \\(2\\)]\\)_RHF\"", 
       "\"(\\!\\(\\*SubscriptBox[\\(sp\\), \\(z\\)]\\)_UHF) ???\"", 
       "\"\\!\\(\\*SuperscriptBox[SubscriptBox[\\(p\\), \\(z\\)], \
\\(2\\)]\\)_RHF\"", "\"sb_RHF/h_RHF\"", "\"sb_UHF/h_UHF\""}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.560181`", ",", "0.691569`", ",", "0.194885`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.922526`", ",", "0.385626`", ",", "0.209179`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.3523253333333333, 0.3137493333333333, 
                    0.46756733333333333`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.528488`", ",", "0.470624`", ",", "0.701351`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.528488, 0.470624, 0.701351]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.528488, 0.470624, 0.701351], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{{3.802668460045702*^9, 3.802668519796715*^9}, 
   3.802668795952363*^9},
 CellLabel->"Out[91]=",ExpressionUUID->"4d69bb3f-ffa5-41d6-bffa-5f3d6ae9c174"]
}, Open  ]],

Cell["\<\
For R > 0:
-the sb_RHF solution is a maximum and exist for R>75/38 (~1.97) before it is \
a holomorphic solution
-the sb_UHF solution is a minimum and exist for R>3/2  before it is a \
holomorphic solution
For R<0:
-the sb_RHF solution is a minimum and exist for R<-3/2 after it is a \
holomorphic solution
-the sb_UHF solution is a maximum and exist for R<-75/62(~1.2) after it is a \
holomorphic solution
\
\>", "Text",
 CellChangeTimes->{{3.8026686832333937`*^9, 3.802668762689664*^9}, {
  3.802668834548761*^9, 3.802668934200431*^9}, {3.802669000876622*^9, 
  3.8026690212528677`*^9}},ExpressionUUID->"e6c814d3-152f-474c-9a5d-\
258e5890aebb"],

Cell["\<\
Those points are the Coulson-Fischer points of the sb-RHF and sb-UHF \
solutions.\
\>", "Text",
 CellChangeTimes->{{3.802669026521483*^9, 3.802669062327118*^9}, {
  3.802669104087213*^9, 
  3.802669107262231*^9}},ExpressionUUID->"1f9addd7-b8df-4373-811c-\
2771135ef044"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1200., 636.75},
WindowMargins->{{0, Automatic}, {0, Automatic}},
TaggingRules->{"TryRealOnly" -> False},
FrontEndVersion->"12.1 for Linux x86 (64-bit) (March 18, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"f4d441e1-0261-4930-998c-befacdc1f025"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 157, 3, 98, "Title",ExpressionUUID->"ada8eced-57b5-4e95-9679-10c23e57e050"],
Cell[740, 27, 523, 12, 46, "Input",ExpressionUUID->"cddd0ec0-6b45-4f98-97fa-10a30d36a12a",
 InitializationCell->True],
Cell[1266, 41, 807, 17, 87, "Input",ExpressionUUID->"999c762a-7c58-4666-bb60-666ecc942fc6",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[2110, 63, 183, 3, 98, "Title",ExpressionUUID->"4fc18051-e9c0-4c5b-a384-aca352fcc60f"],
Cell[2296, 68, 194, 3, 35, "Text",ExpressionUUID->"0fbf1705-90d8-4972-a010-12f7a06f12e2"],
Cell[CellGroupData[{
Cell[2515, 75, 5692, 133, 168, "Input",ExpressionUUID->"f6e7f160-010f-4779-b1d8-ea0c5ba6e8be",
 InitializationCell->True],
Cell[8210, 210, 670, 13, 22, "Message",ExpressionUUID->"f43690ac-2534-4e52-bdc4-1b11abdb3894"],
Cell[8883, 225, 670, 13, 22, "Message",ExpressionUUID->"6e1120df-ba71-4a86-a8bb-49a8e2ae428c"],
Cell[9556, 240, 670, 13, 22, "Message",ExpressionUUID->"ab2d3936-24d8-4f9d-8ec1-a120d0475c73"],
Cell[10229, 255, 478, 10, 22, "Message",ExpressionUUID->"101a719a-022c-4807-b0cb-e7e72c39686f"]
}, Open  ]],
Cell[10722, 268, 174, 3, 35, "Text",ExpressionUUID->"231d3157-529b-4bc7-a840-df39d8f184e9"],
Cell[CellGroupData[{
Cell[10921, 275, 896, 28, 30, "Input",ExpressionUUID->"6602dda8-5b82-4835-a2a6-e1e0a1c0e32e"],
Cell[11820, 305, 18044, 636, 803, "Output",ExpressionUUID->"83464c67-066b-4f31-832c-f92b96a255d9"]
}, Open  ]],
Cell[29879, 944, 264, 5, 35, "Text",ExpressionUUID->"8ada797e-51a3-42f5-9b78-7dc023472d79"],
Cell[30146, 951, 9947, 325, 455, "Input",ExpressionUUID->"bc0a02bd-ce9f-4092-ba29-455868247a72",
 InitializationCell->True],
Cell[40096, 1278, 9888, 324, 455, "Input",ExpressionUUID->"a0467d14-fb57-4673-a6fc-eaba9b401d4f",
 InitializationCell->True],
Cell[49987, 1604, 184, 3, 35, "Text",ExpressionUUID->"5284d7aa-c7f1-4ca8-913e-1f30fc96cd74"],
Cell[50174, 1609, 1325, 44, 70, "Input",ExpressionUUID->"89897658-b4e4-4283-b38e-d848aa34e2ac",
 InitializationCell->True],
Cell[51502, 1655, 287, 4, 35, "Text",ExpressionUUID->"129c7a17-7cbb-4633-8227-b25198d13382"],
Cell[CellGroupData[{
Cell[51814, 1663, 2547, 72, 133, "Input",ExpressionUUID->"24664069-d643-46e2-b730-262853885865"],
Cell[54364, 1737, 646, 13, 22, "Message",ExpressionUUID->"2a50fb86-b8d7-40ae-ab20-633f5f3b2658"],
Cell[55013, 1752, 646, 13, 22, "Message",ExpressionUUID->"8e5f854e-ea62-408b-b6d4-660ed995520d"],
Cell[55662, 1767, 646, 13, 22, "Message",ExpressionUUID->"a97faec4-d943-42c9-8686-d309da1ca613"],
Cell[56311, 1782, 456, 10, 22, "Message",ExpressionUUID->"7780729a-83df-42f3-9fb1-5b27a8689551"],
Cell[56770, 1794, 1480, 49, 49, "Output",ExpressionUUID->"846297c3-7ab4-4c69-aa0e-df2c493ae434"]
}, Open  ]],
Cell[58265, 1846, 172, 3, 35, "Text",ExpressionUUID->"0f3e01cd-58e9-4bf5-b1bd-194abb9bf7b5"],
Cell[CellGroupData[{
Cell[58462, 1853, 2548, 72, 133, "Input",ExpressionUUID->"858e2df5-f32c-46a7-986d-ee0dd3dd1489"],
Cell[61013, 1927, 646, 13, 22, "Message",ExpressionUUID->"133106f4-2a95-41aa-a9ca-28ca606939bd"],
Cell[61662, 1942, 647, 13, 22, "Message",ExpressionUUID->"fba4887c-6d05-49e9-886c-61e56f50e3a4"],
Cell[62312, 1957, 646, 13, 22, "Message",ExpressionUUID->"32108298-0b16-4037-ba7a-91581c79bf6f"],
Cell[62961, 1972, 455, 10, 22, "Message",ExpressionUUID->"d195f59e-76b0-4895-92bd-104a79b47961"],
Cell[63419, 1984, 1428, 47, 49, "Output",ExpressionUUID->"d3c978a7-f654-42e8-9d18-ac84427124ce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64884, 2036, 160, 3, 68, "Section",ExpressionUUID->"8bc81dc5-3e8b-48e8-9f7a-d3219da34091"],
Cell[65047, 2041, 177, 3, 35, "Text",ExpressionUUID->"4592d0bc-14a6-441d-b2c8-840c4f56bace"],
Cell[CellGroupData[{
Cell[65249, 2048, 375, 8, 29, "Input",ExpressionUUID->"3abfa35e-224a-4093-b094-7ec8ae51fcc0"],
Cell[65627, 2058, 7137, 248, 201, "Output",ExpressionUUID->"1358b260-fa3c-43c8-8085-d0506d6c1731"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72801, 2311, 328, 7, 29, "Input",ExpressionUUID->"a0575948-9a8d-4e4e-95a4-9d9847c0e597"],
Cell[73132, 2320, 7189, 249, 201, "Output",ExpressionUUID->"73363abd-4022-4483-a513-16a095022a5c"]
}, Open  ]],
Cell[80336, 2572, 144, 3, 35, "Text",ExpressionUUID->"ebc3853e-526b-48a5-81bb-7a9f30466437"],
Cell[80483, 2577, 239, 6, 35, "Text",ExpressionUUID->"e3b49f5d-3aad-49ed-a3c1-faf6e92e1b06"],
Cell[CellGroupData[{
Cell[80747, 2587, 1625, 54, 46, "Input",ExpressionUUID->"5197a90f-f38e-4136-83da-21ce5f4572fd"],
Cell[82375, 2643, 2408, 74, 66, "Output",ExpressionUUID->"3bacbe2a-e9be-448c-af54-b21efa2bf2c1"]
}, Open  ]],
Cell[84798, 2720, 915, 21, 58, "Text",ExpressionUUID->"3d90d84f-877a-4e43-b9c0-1030bf3f0df5"],
Cell[CellGroupData[{
Cell[85738, 2745, 2149, 67, 78, "Input",ExpressionUUID->"6810a691-9e34-44be-88e5-257f5a8c1ac6"],
Cell[87890, 2814, 1008, 34, 50, "Output",ExpressionUUID->"f4a0ea68-29b7-4b88-8111-587d0e775312"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88935, 2853, 411, 12, 47, "Input",ExpressionUUID->"5860bde6-0c0c-4201-8a77-3e9ee0d2ed2f"],
Cell[89349, 2867, 293, 7, 48, "Output",ExpressionUUID->"0bba0f28-b669-493b-8c39-a3d7c1476497"]
}, Open  ]],
Cell[CellGroupData[{
Cell[89679, 2879, 1122, 34, 46, "Input",ExpressionUUID->"9a6badb7-ed47-40b0-8085-24c5bc98241e"],
Cell[90804, 2915, 63760, 1166, 242, "Output",ExpressionUUID->"26ac9f7a-2ee6-49e0-b0ac-59e073e25c7d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[154601, 4086, 1155, 34, 46, "Input",ExpressionUUID->"8b8bc894-1909-4f82-8fc2-be6f3932aa91"],
Cell[155759, 4122, 32396, 643, 243, "Output",ExpressionUUID->"bbc68235-4dbc-49c4-9812-3800209db685"]
}, Open  ]],
Cell[CellGroupData[{
Cell[188192, 4770, 430, 12, 46, "Input",ExpressionUUID->"0d8a6035-f32d-4793-b1ca-f87b3610e89e"],
Cell[188625, 4784, 275, 6, 48, "Output",ExpressionUUID->"ad0d2235-147f-4518-87c1-4dd62e352642"]
}, Open  ]],
Cell[CellGroupData[{
Cell[188937, 4795, 1120, 34, 46, "Input",ExpressionUUID->"fcf7baa2-6f77-4232-a400-15762d5e1fd2"],
Cell[190060, 4831, 45723, 862, 246, "Output",ExpressionUUID->"e38e86a5-c37d-49fe-b290-a6b33e450513"]
}, Open  ]],
Cell[CellGroupData[{
Cell[235820, 5698, 404, 11, 45, "Input",ExpressionUUID->"37a432a5-9212-4f69-bd4f-ee45ce14d63e"],
Cell[236227, 5711, 268, 7, 48, "Output",ExpressionUUID->"491e73c8-dfa7-4aa6-b488-9857bfe4c759"]
}, Open  ]],
Cell[236510, 5721, 508, 9, 58, "Text",ExpressionUUID->"76876f74-21ed-474a-9a9d-85f07d24750a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[237055, 5735, 157, 3, 68, "Section",ExpressionUUID->"afaead18-5e78-459a-ab9e-1f6826e79431"],
Cell[CellGroupData[{
Cell[237237, 5742, 276, 6, 29, "Input",ExpressionUUID->"ddc4bd4f-72ca-4be7-a6bf-141af9605a4f"],
Cell[237516, 5750, 12632, 436, 430, "Output",ExpressionUUID->"0304661f-7af8-4f41-b828-7bd37ba7d9a5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[250185, 6191, 277, 6, 29, "Input",ExpressionUUID->"216c684a-3ac3-4c0d-a1f6-4efc7954c120"],
Cell[250465, 6199, 12630, 436, 430, "Output",ExpressionUUID->"45ba14ae-03dd-4070-8498-e92ca6359f4d"]
}, Open  ]],
Cell[263110, 6638, 253, 6, 35, "Text",ExpressionUUID->"5132ca1c-5086-4049-9d9f-539d706507a7"],
Cell[CellGroupData[{
Cell[263388, 6648, 2570, 80, 90, "Input",ExpressionUUID->"e6c9e6cd-90db-4d44-8da0-ad3de2b383ae"],
Cell[265961, 6730, 2472, 74, 66, "Output",ExpressionUUID->"8d831873-d11c-439e-8414-7a5eeceb49b1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[268470, 6809, 1942, 63, 78, "Input",ExpressionUUID->"4945a4b2-10d0-4dd0-9b6e-5417c74af8d9"],
Cell[270415, 6874, 901, 30, 50, "Output",ExpressionUUID->"c57481c5-e784-4645-b3d3-1b54cd4cb2ba"]
}, Open  ]],
Cell[CellGroupData[{
Cell[271353, 6909, 1296, 39, 75, "Input",ExpressionUUID->"5b1e83e0-e5a5-4a98-b6c9-1c4db1bebccf"],
Cell[272652, 6950, 76525, 1396, 248, "Output",ExpressionUUID->"fe2e4aca-1faa-45c3-8155-20096138d09c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[349214, 8351, 1326, 39, 75, "Input",ExpressionUUID->"e096d0b5-6194-4b39-b564-43c2120b307f"],
Cell[350543, 8392, 37948, 752, 240, "Output",ExpressionUUID->"0194e55a-69d4-4f78-9043-1ffc49c4ff4b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[388528, 9149, 1270, 39, 75, "Input",ExpressionUUID->"6e2f0f8e-60db-4310-8763-4994effde913"],
Cell[389801, 9190, 58300, 1087, 241, "Output",ExpressionUUID->"93354289-5870-4a58-8645-15687481f6f5"]
}, Open  ]],
Cell[448116, 10280, 772, 14, 127, "Text",ExpressionUUID->"789a8640-f72d-4922-b335-731b29963b66"]
}, Open  ]],
Cell[CellGroupData[{
Cell[448925, 10299, 162, 3, 68, "Section",ExpressionUUID->"bde0567b-610f-4ced-b3c2-7e3d365cb7c7"],
Cell[CellGroupData[{
Cell[449112, 10306, 817, 19, 29, "Input",ExpressionUUID->"7a8160f0-d63e-44ba-bf07-5585a342b529"],
Cell[449932, 10327, 1155, 36, 50, "Output",ExpressionUUID->"e68ed154-12f0-46b6-9989-c127efd9455e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[451124, 10368, 1786, 49, 75, "Input",ExpressionUUID->"19e9fcc3-462d-4146-8b67-65de6066d591"],
Cell[452913, 10419, 32738, 649, 240, "Output",ExpressionUUID->"54f8084a-0a1a-41e6-ad4a-e23c2b5d4588"]
}, Open  ]],
Cell[CellGroupData[{
Cell[485688, 11073, 1632, 48, 75, "Input",ExpressionUUID->"0f9b8d2a-dca6-4a62-bd03-16a3aed40353"],
Cell[487323, 11123, 36675, 713, 238, "Output",ExpressionUUID->"4d69bb3f-ffa5-41d6-bffa-5f3d6ae9c174"]
}, Open  ]],
Cell[524013, 11839, 656, 16, 173, "Text",ExpressionUUID->"e6c814d3-152f-474c-9a5d-258e5890aebb"],
Cell[524672, 11857, 280, 7, 35, "Text",ExpressionUUID->"1f9addd7-b8df-4373-811c-2771135ef044"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

